In perl.git, the branch blead has been updated

<http://perl5.git.perl.org/perl.git/commitdiff/fcd4e2f8c97d60e18fb7288412b1903388692000?hp=5585e758ec847fcd75936b77096edf5234d6e0c0>

- Log -----------------------------------------------------------------
commit fcd4e2f8c97d60e18fb7288412b1903388692000
Author: Steve Hay <[email protected]>
Date:   Tue Nov 1 17:44:52 2016 +0000

    Upgrade Unicode::Collate from version 1.14 to 1.17

M       MANIFEST
M       Porting/Maintainers.pl
M       cpan/Unicode-Collate/Collate.pm
M       cpan/Unicode-Collate/Collate.xs
M       cpan/Unicode-Collate/Collate/CJK/Big5.pm
M       cpan/Unicode-Collate/Collate/CJK/GB2312.pm
M       cpan/Unicode-Collate/Collate/CJK/JISX0208.pm
M       cpan/Unicode-Collate/Collate/CJK/Korean.pm
M       cpan/Unicode-Collate/Collate/CJK/Pinyin.pm
M       cpan/Unicode-Collate/Collate/CJK/Stroke.pm
M       cpan/Unicode-Collate/Collate/CJK/Zhuyin.pm
M       cpan/Unicode-Collate/Collate/Locale.pm
M       cpan/Unicode-Collate/Collate/Locale/af.pl
M       cpan/Unicode-Collate/Collate/Locale/ar.pl
M       cpan/Unicode-Collate/Collate/Locale/as.pl
M       cpan/Unicode-Collate/Collate/Locale/az.pl
M       cpan/Unicode-Collate/Collate/Locale/be.pl
D       cpan/Unicode-Collate/Collate/Locale/bg.pl
M       cpan/Unicode-Collate/Collate/Locale/bn.pl
M       cpan/Unicode-Collate/Collate/Locale/ca.pl
M       cpan/Unicode-Collate/Collate/Locale/cs.pl
M       cpan/Unicode-Collate/Collate/Locale/cy.pl
M       cpan/Unicode-Collate/Collate/Locale/da.pl
M       cpan/Unicode-Collate/Collate/Locale/de_phone.pl
M       cpan/Unicode-Collate/Collate/Locale/ee.pl
M       cpan/Unicode-Collate/Collate/Locale/eo.pl
M       cpan/Unicode-Collate/Collate/Locale/es.pl
M       cpan/Unicode-Collate/Collate/Locale/es_trad.pl
M       cpan/Unicode-Collate/Collate/Locale/et.pl
M       cpan/Unicode-Collate/Collate/Locale/fa.pl
M       cpan/Unicode-Collate/Collate/Locale/fi.pl
M       cpan/Unicode-Collate/Collate/Locale/fi_phone.pl
M       cpan/Unicode-Collate/Collate/Locale/fil.pl
M       cpan/Unicode-Collate/Collate/Locale/fo.pl
M       cpan/Unicode-Collate/Collate/Locale/fr.pl
M       cpan/Unicode-Collate/Collate/Locale/gu.pl
M       cpan/Unicode-Collate/Collate/Locale/ha.pl
M       cpan/Unicode-Collate/Collate/Locale/haw.pl
M       cpan/Unicode-Collate/Collate/Locale/hi.pl
M       cpan/Unicode-Collate/Collate/Locale/hr.pl
M       cpan/Unicode-Collate/Collate/Locale/hu.pl
M       cpan/Unicode-Collate/Collate/Locale/hy.pl
M       cpan/Unicode-Collate/Collate/Locale/ig.pl
M       cpan/Unicode-Collate/Collate/Locale/is.pl
M       cpan/Unicode-Collate/Collate/Locale/ja.pl
M       cpan/Unicode-Collate/Collate/Locale/kk.pl
M       cpan/Unicode-Collate/Collate/Locale/kl.pl
M       cpan/Unicode-Collate/Collate/Locale/kn.pl
M       cpan/Unicode-Collate/Collate/Locale/ko.pl
M       cpan/Unicode-Collate/Collate/Locale/kok.pl
M       cpan/Unicode-Collate/Collate/Locale/ln.pl
M       cpan/Unicode-Collate/Collate/Locale/lt.pl
M       cpan/Unicode-Collate/Collate/Locale/lv.pl
M       cpan/Unicode-Collate/Collate/Locale/mk.pl
M       cpan/Unicode-Collate/Collate/Locale/ml.pl
M       cpan/Unicode-Collate/Collate/Locale/mr.pl
M       cpan/Unicode-Collate/Collate/Locale/mt.pl
M       cpan/Unicode-Collate/Collate/Locale/nb.pl
M       cpan/Unicode-Collate/Collate/Locale/nn.pl
M       cpan/Unicode-Collate/Collate/Locale/nso.pl
M       cpan/Unicode-Collate/Collate/Locale/om.pl
M       cpan/Unicode-Collate/Collate/Locale/or.pl
M       cpan/Unicode-Collate/Collate/Locale/pa.pl
M       cpan/Unicode-Collate/Collate/Locale/pl.pl
M       cpan/Unicode-Collate/Collate/Locale/ro.pl
D       cpan/Unicode-Collate/Collate/Locale/ru.pl
M       cpan/Unicode-Collate/Collate/Locale/sa.pl
M       cpan/Unicode-Collate/Collate/Locale/se.pl
M       cpan/Unicode-Collate/Collate/Locale/si.pl
M       cpan/Unicode-Collate/Collate/Locale/si_dict.pl
M       cpan/Unicode-Collate/Collate/Locale/sk.pl
M       cpan/Unicode-Collate/Collate/Locale/sl.pl
M       cpan/Unicode-Collate/Collate/Locale/sq.pl
M       cpan/Unicode-Collate/Collate/Locale/sr.pl
M       cpan/Unicode-Collate/Collate/Locale/sv.pl
M       cpan/Unicode-Collate/Collate/Locale/sv_refo.pl
M       cpan/Unicode-Collate/Collate/Locale/ta.pl
M       cpan/Unicode-Collate/Collate/Locale/te.pl
M       cpan/Unicode-Collate/Collate/Locale/th.pl
M       cpan/Unicode-Collate/Collate/Locale/tn.pl
M       cpan/Unicode-Collate/Collate/Locale/to.pl
M       cpan/Unicode-Collate/Collate/Locale/tr.pl
A       cpan/Unicode-Collate/Collate/Locale/ug_cyrl.pl
M       cpan/Unicode-Collate/Collate/Locale/uk.pl
M       cpan/Unicode-Collate/Collate/Locale/ur.pl
M       cpan/Unicode-Collate/Collate/Locale/vi.pl
M       cpan/Unicode-Collate/Collate/Locale/wae.pl
M       cpan/Unicode-Collate/Collate/Locale/wo.pl
M       cpan/Unicode-Collate/Collate/Locale/yo.pl
M       cpan/Unicode-Collate/Collate/Locale/zh.pl
M       cpan/Unicode-Collate/Collate/Locale/zh_big5.pl
M       cpan/Unicode-Collate/Collate/Locale/zh_gb.pl
M       cpan/Unicode-Collate/Collate/Locale/zh_pin.pl
M       cpan/Unicode-Collate/Collate/Locale/zh_strk.pl
M       cpan/Unicode-Collate/Collate/Locale/zh_zhu.pl
M       cpan/Unicode-Collate/Collate/allkeys.txt
M       cpan/Unicode-Collate/t/cjkrange.t
M       cpan/Unicode-Collate/t/compatui.t
M       cpan/Unicode-Collate/t/default.t
M       cpan/Unicode-Collate/t/hangtype.t
M       cpan/Unicode-Collate/t/illegal.t
M       cpan/Unicode-Collate/t/loc_be.t
M       cpan/Unicode-Collate/t/loc_bg.t
M       cpan/Unicode-Collate/t/loc_bscy.t
M       cpan/Unicode-Collate/t/loc_cyrl.t
M       cpan/Unicode-Collate/t/loc_es.t
M       cpan/Unicode-Collate/t/loc_estr.t
M       cpan/Unicode-Collate/t/loc_fr.t
M       cpan/Unicode-Collate/t/loc_kk.t
M       cpan/Unicode-Collate/t/loc_mk.t
A       cpan/Unicode-Collate/t/loc_mncy.t
M       cpan/Unicode-Collate/t/loc_ru.t
M       cpan/Unicode-Collate/t/loc_sr.t
M       cpan/Unicode-Collate/t/loc_sw.t
A       cpan/Unicode-Collate/t/loc_ugcy.t
M       cpan/Unicode-Collate/t/loc_uk.t
M       cpan/Unicode-Collate/t/overcjk0.t
M       cpan/Unicode-Collate/t/overcjk1.t
M       cpan/Unicode-Collate/t/version.t
M       cpan/Unicode-Collate/t/view.t

commit c59be0827018418e40637878369155d288da3cf2
Author: Steve Hay <[email protected]>
Date:   Tue Nov 1 17:35:01 2016 +0000

    Upgrade Test::Simple from version 1.302059 to 1.302062

M       MANIFEST
M       Porting/Maintainers.pl
M       cpan/Test-Simple/lib/Test/Builder.pm
M       cpan/Test-Simple/lib/Test/Builder/Formatter.pm
M       cpan/Test-Simple/lib/Test/Builder/Module.pm
M       cpan/Test-Simple/lib/Test/Builder/Tester.pm
M       cpan/Test-Simple/lib/Test/Builder/Tester/Color.pm
M       cpan/Test-Simple/lib/Test/Builder/TodoDiag.pm
M       cpan/Test-Simple/lib/Test/More.pm
M       cpan/Test-Simple/lib/Test/Simple.pm
M       cpan/Test-Simple/lib/Test/Tester.pm
M       cpan/Test-Simple/lib/Test/Tester/Capture.pm
M       cpan/Test-Simple/lib/Test/Tester/CaptureRunner.pm
M       cpan/Test-Simple/lib/Test/Tester/Delegate.pm
M       cpan/Test-Simple/lib/Test/use/ok.pm
M       cpan/Test-Simple/lib/Test2.pm
M       cpan/Test-Simple/lib/Test2/API.pm
M       cpan/Test-Simple/lib/Test2/API/Breakage.pm
M       cpan/Test-Simple/lib/Test2/API/Context.pm
M       cpan/Test-Simple/lib/Test2/API/Instance.pm
M       cpan/Test-Simple/lib/Test2/API/Stack.pm
M       cpan/Test-Simple/lib/Test2/Event.pm
M       cpan/Test-Simple/lib/Test2/Event/Bail.pm
M       cpan/Test-Simple/lib/Test2/Event/Diag.pm
M       cpan/Test-Simple/lib/Test2/Event/Exception.pm
M       cpan/Test-Simple/lib/Test2/Event/Generic.pm
M       cpan/Test-Simple/lib/Test2/Event/Info.pm
M       cpan/Test-Simple/lib/Test2/Event/Note.pm
M       cpan/Test-Simple/lib/Test2/Event/Ok.pm
M       cpan/Test-Simple/lib/Test2/Event/Plan.pm
M       cpan/Test-Simple/lib/Test2/Event/Skip.pm
M       cpan/Test-Simple/lib/Test2/Event/Subtest.pm
M       cpan/Test-Simple/lib/Test2/Event/Waiting.pm
M       cpan/Test-Simple/lib/Test2/Formatter.pm
M       cpan/Test-Simple/lib/Test2/Formatter/TAP.pm
M       cpan/Test-Simple/lib/Test2/Hub.pm
M       cpan/Test-Simple/lib/Test2/Hub/Interceptor.pm
M       cpan/Test-Simple/lib/Test2/Hub/Interceptor/Terminator.pm
M       cpan/Test-Simple/lib/Test2/Hub/Subtest.pm
M       cpan/Test-Simple/lib/Test2/IPC.pm
M       cpan/Test-Simple/lib/Test2/IPC/Driver.pm
M       cpan/Test-Simple/lib/Test2/IPC/Driver/Files.pm
M       cpan/Test-Simple/lib/Test2/Util.pm
M       cpan/Test-Simple/lib/Test2/Util/ExternalMeta.pm
M       cpan/Test-Simple/lib/Test2/Util/HashBase.pm
M       cpan/Test-Simple/lib/Test2/Util/Trace.pm
M       cpan/Test-Simple/lib/ok.pm
M       cpan/Test-Simple/t/Legacy/missing.t
A       cpan/Test-Simple/t/Test2/behavior/Formatter.t
M       cpan/Test-Simple/t/Test2/behavior/Subtest_buffer_formatter.t
M       cpan/Test-Simple/t/Test2/behavior/no_load_api.t

commit 93d7ac13d34e6b9246990d232910a98d65549808
Author: Steve Hay <[email protected]>
Date:   Tue Nov 1 17:29:33 2016 +0000

    Upgrade Term::ANSIColor from version 4.05 to 4.06

M       Porting/Maintainers.pl
M       cpan/Term-ANSIColor/lib/Term/ANSIColor.pm
M       cpan/Term-ANSIColor/t/lib/Test/RRA.pm
M       cpan/Term-ANSIColor/t/lib/Test/RRA/Config.pm
M       cpan/Term-ANSIColor/t/module/basic256.t
-----------------------------------------------------------------------

Summary of changes:
 MANIFEST                                           |     6 +-
 Porting/Maintainers.pl                             |     7 +-
 cpan/Term-ANSIColor/lib/Term/ANSIColor.pm          |    49 +-
 cpan/Term-ANSIColor/t/lib/Test/RRA.pm              |    51 +-
 cpan/Term-ANSIColor/t/lib/Test/RRA/Config.pm       |    30 +-
 cpan/Term-ANSIColor/t/module/basic256.t            |    20 +-
 cpan/Test-Simple/lib/Test/Builder.pm               |     6 +-
 cpan/Test-Simple/lib/Test/Builder/Formatter.pm     |     2 +-
 cpan/Test-Simple/lib/Test/Builder/Module.pm        |     2 +-
 cpan/Test-Simple/lib/Test/Builder/Tester.pm        |     2 +-
 cpan/Test-Simple/lib/Test/Builder/Tester/Color.pm  |     2 +-
 cpan/Test-Simple/lib/Test/Builder/TodoDiag.pm      |     2 +-
 cpan/Test-Simple/lib/Test/More.pm                  |     2 +-
 cpan/Test-Simple/lib/Test/Simple.pm                |     2 +-
 cpan/Test-Simple/lib/Test/Tester.pm                |     2 +-
 cpan/Test-Simple/lib/Test/Tester/Capture.pm        |     2 +-
 cpan/Test-Simple/lib/Test/Tester/CaptureRunner.pm  |     2 +-
 cpan/Test-Simple/lib/Test/Tester/Delegate.pm       |     2 +-
 cpan/Test-Simple/lib/Test/use/ok.pm                |     2 +-
 cpan/Test-Simple/lib/Test2.pm                      |     2 +-
 cpan/Test-Simple/lib/Test2/API.pm                  |     2 +-
 cpan/Test-Simple/lib/Test2/API/Breakage.pm         |     2 +-
 cpan/Test-Simple/lib/Test2/API/Context.pm          |     2 +-
 cpan/Test-Simple/lib/Test2/API/Instance.pm         |     2 +-
 cpan/Test-Simple/lib/Test2/API/Stack.pm            |     2 +-
 cpan/Test-Simple/lib/Test2/Event.pm                |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Bail.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Diag.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Exception.pm      |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Generic.pm        |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Info.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Note.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Ok.pm             |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Plan.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Skip.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Subtest.pm        |     2 +-
 cpan/Test-Simple/lib/Test2/Event/Waiting.pm        |     2 +-
 cpan/Test-Simple/lib/Test2/Formatter.pm            |    36 +-
 cpan/Test-Simple/lib/Test2/Formatter/TAP.pm        |     2 +-
 cpan/Test-Simple/lib/Test2/Hub.pm                  |    22 +-
 cpan/Test-Simple/lib/Test2/Hub/Interceptor.pm      |     2 +-
 .../lib/Test2/Hub/Interceptor/Terminator.pm        |     2 +-
 cpan/Test-Simple/lib/Test2/Hub/Subtest.pm          |     4 +-
 cpan/Test-Simple/lib/Test2/IPC.pm                  |     2 +-
 cpan/Test-Simple/lib/Test2/IPC/Driver.pm           |     2 +-
 cpan/Test-Simple/lib/Test2/IPC/Driver/Files.pm     |     2 +-
 cpan/Test-Simple/lib/Test2/Util.pm                 |     2 +-
 cpan/Test-Simple/lib/Test2/Util/ExternalMeta.pm    |     2 +-
 cpan/Test-Simple/lib/Test2/Util/HashBase.pm        |     2 +-
 cpan/Test-Simple/lib/Test2/Util/Trace.pm           |     2 +-
 cpan/Test-Simple/lib/ok.pm                         |     2 +-
 cpan/Test-Simple/t/Legacy/missing.t                |     1 +
 cpan/Test-Simple/t/Test2/behavior/Formatter.t      |    84 +
 .../t/Test2/behavior/Subtest_buffer_formatter.t    |    10 +-
 cpan/Test-Simple/t/Test2/behavior/no_load_api.t    |     1 +
 cpan/Unicode-Collate/Collate.pm                    |    24 +-
 cpan/Unicode-Collate/Collate.xs                    |    16 +-
 cpan/Unicode-Collate/Collate/CJK/Big5.pm           |     2 +-
 cpan/Unicode-Collate/Collate/CJK/GB2312.pm         |     2 +-
 cpan/Unicode-Collate/Collate/CJK/JISX0208.pm       |     2 +-
 cpan/Unicode-Collate/Collate/CJK/Korean.pm         |    26 +-
 cpan/Unicode-Collate/Collate/CJK/Pinyin.pm         |     2 +-
 cpan/Unicode-Collate/Collate/CJK/Stroke.pm         |     2 +-
 cpan/Unicode-Collate/Collate/CJK/Zhuyin.pm         |     2 +-
 cpan/Unicode-Collate/Collate/Locale.pm             |   206 +-
 cpan/Unicode-Collate/Collate/Locale/af.pl          |     6 +-
 cpan/Unicode-Collate/Collate/Locale/ar.pl          |    24 +-
 cpan/Unicode-Collate/Collate/Locale/as.pl          |    20 +-
 cpan/Unicode-Collate/Collate/Locale/az.pl          |    94 +-
 cpan/Unicode-Collate/Collate/Locale/be.pl          |    50 +-
 cpan/Unicode-Collate/Collate/Locale/bg.pl          |    45 -
 cpan/Unicode-Collate/Collate/Locale/bn.pl          |    12 +-
 cpan/Unicode-Collate/Collate/Locale/ca.pl          |    28 +-
 cpan/Unicode-Collate/Collate/Locale/cs.pl          |    44 +-
 cpan/Unicode-Collate/Collate/Locale/cy.pl          |    52 +-
 cpan/Unicode-Collate/Collate/Locale/da.pl          |   148 +-
 cpan/Unicode-Collate/Collate/Locale/de_phone.pl    |    52 +-
 cpan/Unicode-Collate/Collate/Locale/ee.pl          |    62 +-
 cpan/Unicode-Collate/Collate/Locale/eo.pl          |    52 +-
 cpan/Unicode-Collate/Collate/Locale/es.pl          |    12 +-
 cpan/Unicode-Collate/Collate/Locale/es_trad.pl     |    24 +-
 cpan/Unicode-Collate/Collate/Locale/et.pl          |   100 +-
 cpan/Unicode-Collate/Collate/Locale/fa.pl          |    88 +-
 cpan/Unicode-Collate/Collate/Locale/fi.pl          |   122 +-
 cpan/Unicode-Collate/Collate/Locale/fi_phone.pl    |   118 +-
 cpan/Unicode-Collate/Collate/Locale/fil.pl         |    18 +-
 cpan/Unicode-Collate/Collate/Locale/fo.pl          |   148 +-
 cpan/Unicode-Collate/Collate/Locale/fr.pl          |     2 +-
 cpan/Unicode-Collate/Collate/Locale/gu.pl          |    12 +-
 cpan/Unicode-Collate/Collate/Locale/ha.pl          |    24 +-
 cpan/Unicode-Collate/Collate/Locale/haw.pl         |    68 +-
 cpan/Unicode-Collate/Collate/Locale/hi.pl          |    12 +-
 cpan/Unicode-Collate/Collate/Locale/hr.pl          |    90 +-
 cpan/Unicode-Collate/Collate/Locale/hu.pl          |   296 +-
 cpan/Unicode-Collate/Collate/Locale/hy.pl          |    12 +-
 cpan/Unicode-Collate/Collate/Locale/ig.pl          |   102 +-
 cpan/Unicode-Collate/Collate/Locale/is.pl          |   156 +-
 cpan/Unicode-Collate/Collate/Locale/ja.pl          |  2632 +-
 cpan/Unicode-Collate/Collate/Locale/kk.pl          |    60 +-
 cpan/Unicode-Collate/Collate/Locale/kl.pl          |   144 +-
 cpan/Unicode-Collate/Collate/Locale/kn.pl          |    14 +-
 cpan/Unicode-Collate/Collate/Locale/ko.pl          |  1284 +-
 cpan/Unicode-Collate/Collate/Locale/kok.pl         |    20 +-
 cpan/Unicode-Collate/Collate/Locale/ln.pl          |    18 +-
 cpan/Unicode-Collate/Collate/Locale/lt.pl          |    82 +-
 cpan/Unicode-Collate/Collate/Locale/lv.pl          |    68 +-
 cpan/Unicode-Collate/Collate/Locale/mk.pl          |    59 +-
 cpan/Unicode-Collate/Collate/Locale/ml.pl          |    40 +-
 cpan/Unicode-Collate/Collate/Locale/mr.pl          |    22 +-
 cpan/Unicode-Collate/Collate/Locale/mt.pl          |    54 +-
 cpan/Unicode-Collate/Collate/Locale/nb.pl          |   146 +-
 cpan/Unicode-Collate/Collate/Locale/nn.pl          |   146 +-
 cpan/Unicode-Collate/Collate/Locale/nso.pl         |    68 +-
 cpan/Unicode-Collate/Collate/Locale/om.pl          |    38 +-
 cpan/Unicode-Collate/Collate/Locale/or.pl          |    18 +-
 cpan/Unicode-Collate/Collate/Locale/pa.pl          |    48 +-
 cpan/Unicode-Collate/Collate/Locale/pl.pl          |    96 +-
 cpan/Unicode-Collate/Collate/Locale/ro.pl          |   100 +-
 cpan/Unicode-Collate/Collate/Locale/ru.pl          |    45 -
 cpan/Unicode-Collate/Collate/Locale/sa.pl          |    22 +-
 cpan/Unicode-Collate/Collate/Locale/se.pl          |   292 +-
 cpan/Unicode-Collate/Collate/Locale/si.pl          |    14 +-
 cpan/Unicode-Collate/Collate/Locale/si_dict.pl     |    12 +-
 cpan/Unicode-Collate/Collate/Locale/sk.pl          |    84 +-
 cpan/Unicode-Collate/Collate/Locale/sl.pl          |    28 +-
 cpan/Unicode-Collate/Collate/Locale/sq.pl          |    92 +-
 cpan/Unicode-Collate/Collate/Locale/sr.pl          |    51 +-
 cpan/Unicode-Collate/Collate/Locale/sv.pl          |   172 +-
 cpan/Unicode-Collate/Collate/Locale/sv_refo.pl     |   168 +-
 cpan/Unicode-Collate/Collate/Locale/ta.pl          |   104 +-
 cpan/Unicode-Collate/Collate/Locale/te.pl          |    12 +-
 cpan/Unicode-Collate/Collate/Locale/th.pl          |    36 +-
 cpan/Unicode-Collate/Collate/Locale/tn.pl          |    68 +-
 cpan/Unicode-Collate/Collate/Locale/to.pl          |   118 +-
 cpan/Unicode-Collate/Collate/Locale/tr.pl          |    86 +-
 cpan/Unicode-Collate/Collate/Locale/ug_cyrl.pl     |     7 +
 cpan/Unicode-Collate/Collate/Locale/uk.pl          |    53 +-
 cpan/Unicode-Collate/Collate/Locale/ur.pl          |   144 +-
 cpan/Unicode-Collate/Collate/Locale/vi.pl          |   420 +-
 cpan/Unicode-Collate/Collate/Locale/wae.pl         |    42 +-
 cpan/Unicode-Collate/Collate/Locale/wo.pl          |    56 +-
 cpan/Unicode-Collate/Collate/Locale/yo.pl          |    46 +-
 cpan/Unicode-Collate/Collate/Locale/zh.pl          |   416 +-
 cpan/Unicode-Collate/Collate/Locale/zh_big5.pl     |   416 +-
 cpan/Unicode-Collate/Collate/Locale/zh_gb.pl       |   416 +-
 cpan/Unicode-Collate/Collate/Locale/zh_pin.pl      |   642 +-
 cpan/Unicode-Collate/Collate/Locale/zh_strk.pl     |   642 +-
 cpan/Unicode-Collate/Collate/Locale/zh_zhu.pl      |   642 +-
 cpan/Unicode-Collate/Collate/allkeys.txt           | 52887 ++++++++++---------
 cpan/Unicode-Collate/t/cjkrange.t                  |    23 +-
 cpan/Unicode-Collate/t/compatui.t                  |     4 +-
 cpan/Unicode-Collate/t/default.t                   |     8 +-
 cpan/Unicode-Collate/t/hangtype.t                  |     4 +-
 cpan/Unicode-Collate/t/illegal.t                   |     4 +-
 cpan/Unicode-Collate/t/loc_be.t                    |   311 +-
 cpan/Unicode-Collate/t/loc_bg.t                    |   300 +-
 cpan/Unicode-Collate/t/loc_bscy.t                  |   308 +-
 cpan/Unicode-Collate/t/loc_cyrl.t                  |   205 +-
 cpan/Unicode-Collate/t/loc_es.t                    |     2 +-
 cpan/Unicode-Collate/t/loc_estr.t                  |     2 +-
 cpan/Unicode-Collate/t/loc_fr.t                    |     2 +-
 cpan/Unicode-Collate/t/loc_kk.t                    |   353 +-
 cpan/Unicode-Collate/t/loc_mk.t                    |   330 +-
 cpan/Unicode-Collate/t/loc_mncy.t                  |   208 +
 cpan/Unicode-Collate/t/loc_ru.t                    |   322 +-
 cpan/Unicode-Collate/t/loc_sr.t                    |   308 +-
 cpan/Unicode-Collate/t/loc_sw.t                    |     2 +-
 cpan/Unicode-Collate/t/loc_ugcy.t                  |   194 +
 cpan/Unicode-Collate/t/loc_uk.t                    |   331 +-
 cpan/Unicode-Collate/t/overcjk0.t                  |    20 +-
 cpan/Unicode-Collate/t/overcjk1.t                  |    12 +-
 cpan/Unicode-Collate/t/version.t                   |     4 +-
 cpan/Unicode-Collate/t/view.t                      |     4 +-
 173 files changed, 35899 insertions(+), 33538 deletions(-)
 create mode 100644 cpan/Test-Simple/t/Test2/behavior/Formatter.t
 delete mode 100644 cpan/Unicode-Collate/Collate/Locale/bg.pl
 delete mode 100644 cpan/Unicode-Collate/Collate/Locale/ru.pl
 create mode 100644 cpan/Unicode-Collate/Collate/Locale/ug_cyrl.pl
 create mode 100644 cpan/Unicode-Collate/t/loc_mncy.t
 create mode 100644 cpan/Unicode-Collate/t/loc_ugcy.t

diff --git a/MANIFEST b/MANIFEST
index d2dfa4c..1ffdf0c 100644
--- a/MANIFEST
+++ b/MANIFEST
@@ -2758,6 +2758,7 @@ cpan/Test-Simple/t/Test2/acceptance/try_it_skip.t
 cpan/Test-Simple/t/Test2/acceptance/try_it_threads.t
 cpan/Test-Simple/t/Test2/acceptance/try_it_todo.t
 cpan/Test-Simple/t/Test2/behavior/err_var.t
+cpan/Test-Simple/t/Test2/behavior/Formatter.t
 cpan/Test-Simple/t/Test2/behavior/init_croak.t
 cpan/Test-Simple/t/Test2/behavior/nested_context_exception.t
 cpan/Test-Simple/t/Test2/behavior/no_load_api.t
@@ -2869,7 +2870,6 @@ cpan/Unicode-Collate/Collate/Locale/ar.pl                 
Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/as.pl      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/az.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/be.pl      Unicode::Collate
-cpan/Unicode-Collate/Collate/Locale/bg.pl      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/bn.pl              Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/ca.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/cs.pl                      Unicode::Collate
@@ -2917,7 +2917,6 @@ cpan/Unicode-Collate/Collate/Locale/or.pl Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/pa.pl      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/pl.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/ro.pl                      Unicode::Collate
-cpan/Unicode-Collate/Collate/Locale/ru.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/sa.pl              Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/se.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/si.pl      Unicode::Collate
@@ -2934,6 +2933,7 @@ cpan/Unicode-Collate/Collate/Locale/th.pl Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/tn.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/to.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/tr.pl                      Unicode::Collate
+cpan/Unicode-Collate/Collate/Locale/ug_cyrl.pl                 Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/uk.pl                      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/ur.pl      Unicode::Collate
 cpan/Unicode-Collate/Collate/Locale/vi.pl                      Unicode::Collate
@@ -3020,6 +3020,7 @@ cpan/Unicode-Collate/t/loc_lt.t                   
Unicode::Collate
 cpan/Unicode-Collate/t/loc_lv.t                        Unicode::Collate
 cpan/Unicode-Collate/t/loc_mk.t                        Unicode::Collate
 cpan/Unicode-Collate/t/loc_ml.t        Unicode::Collate
+cpan/Unicode-Collate/t/loc_mncy.t              Unicode::Collate
 cpan/Unicode-Collate/t/loc_mr.t        Unicode::Collate
 cpan/Unicode-Collate/t/loc_mt.t                        Unicode::Collate
 cpan/Unicode-Collate/t/loc_nb.t                        Unicode::Collate
@@ -3050,6 +3051,7 @@ cpan/Unicode-Collate/t/loc_th.t   Unicode::Collate
 cpan/Unicode-Collate/t/loc_tn.t                        Unicode::Collate
 cpan/Unicode-Collate/t/loc_to.t                        Unicode::Collate
 cpan/Unicode-Collate/t/loc_tr.t                        Unicode::Collate
+cpan/Unicode-Collate/t/loc_ugcy.t              Unicode::Collate
 cpan/Unicode-Collate/t/loc_uk.t                        Unicode::Collate
 cpan/Unicode-Collate/t/loc_ur.t        Unicode::Collate
 cpan/Unicode-Collate/t/loc_vi.t                        Unicode::Collate
diff --git a/Porting/Maintainers.pl b/Porting/Maintainers.pl
index 73ab08b..3b93bf3 100755
--- a/Porting/Maintainers.pl
+++ b/Porting/Maintainers.pl
@@ -1078,9 +1078,10 @@ use File::Glob qw(:case);
     },
 
     'Term::ANSIColor' => {
-        'DISTRIBUTION' => 'RRA/Term-ANSIColor-4.05.tar.gz',
+        'DISTRIBUTION' => 'RRA/Term-ANSIColor-4.06.tar.gz',
         'FILES'        => q[cpan/Term-ANSIColor],
         'EXCLUDED'     => [
+            qr{^docs/},
             qr{^examples/},
             qr{^t/data/},
             qr{^t/docs/},
@@ -1176,7 +1177,7 @@ use File::Glob qw(:case);
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302059.tar.gz',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302062.tar.gz',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1313,7 +1314,7 @@ use File::Glob qw(:case);
     },
 
     'Unicode::Collate' => {
-        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-1.14.tar.gz',
+        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-1.17.tar.gz',
         'FILES'        => q[cpan/Unicode-Collate],
         'EXCLUDED'     => [
             qr{N$},
diff --git a/cpan/Term-ANSIColor/lib/Term/ANSIColor.pm 
b/cpan/Term-ANSIColor/lib/Term/ANSIColor.pm
index 1a10edc..730124b 100644
--- a/cpan/Term-ANSIColor/lib/Term/ANSIColor.pm
+++ b/cpan/Term-ANSIColor/lib/Term/ANSIColor.pm
@@ -41,7 +41,7 @@ our $AUTOLOAD;
 # against circular module loading (not that we load any modules, but
 # consistency is good).
 BEGIN {
-    $VERSION = '4.05';
+    $VERSION = '4.06';
 
     # All of the basic supported constants, used in %EXPORT_TAGS.
     my @colorlist = qw(
@@ -62,7 +62,7 @@ BEGIN {
 
     # 256-color constants, used in %EXPORT_TAGS.
     my @colorlist256 = (
-        (map { ("ANSI$_", "ON_ANSI$_") } 0 .. 15),
+        (map { ("ANSI$_", "ON_ANSI$_") } 0 .. 255),
         (map { ("GREY$_", "ON_GREY$_") } 0 .. 23),
     );
     for my $r (0 .. 5) {
@@ -145,8 +145,8 @@ our %ATTRIBUTES = (
 # Generating the 256-color codes involves a lot of codes and offsets that are
 # not helped by turning them into constants.
 
-# The first 16 256-color codes are duplicates of the 16 ANSI colors,
-# included for completeness.
+# The first 16 256-color codes are duplicates of the 16 ANSI colors.  The rest
+# are RBG and greyscale values.
 for my $code (0 .. 15) {
     $ATTRIBUTES{"ansi$code"}    = "38;5;$code";
     $ATTRIBUTES{"on_ansi$code"} = "48;5;$code";
@@ -177,6 +177,15 @@ for my $attr (reverse sort keys %ATTRIBUTES) {
     $ATTRIBUTES_R{ $ATTRIBUTES{$attr} } = $attr;
 }
 
+# Provide ansiN names for all 256 characters to provide a convenient flat
+# namespace if one doesn't want to mess with the RGB and greyscale naming.  Do
+# this after creating %ATTRIBUTES_R since we want to use the canonical names
+# when reversing a color.
+for my $code (16 .. 255) {
+    $ATTRIBUTES{"ansi$code"}    = "38;5;$code";
+    $ATTRIBUTES{"on_ansi$code"} = "48;5;$code";
+}
+
 # Import any custom colors set in the environment.
 our %ALIASES;
 if (exists $ENV{ANSI_COLORS_ALIASES}) {
@@ -695,10 +704,12 @@ sixteen-color emulators but use the 256-color escape 
syntax, C<grey0>
 through C<grey23> ranging from nearly black to nearly white, and a set of
 RGB colors.  The RGB colors are of the form C<rgbI<RGB>> where I<R>, I<G>,
 and I<B> are numbers from 0 to 5 giving the intensity of red, green, and
-blue.  C<on_> variants of all of these colors are also provided.  These
-colors may be ignored completely on non-256-color terminals or may be
-misinterpreted and produce random behavior.  Additional attributes such as
-blink, italic, or bold may not work with the 256-color palette.
+blue.  The grey and RGB colors are also available as C<ansi16> through
+C<ansi255> if you want simple names for all 256 colors.  C<on_> variants
+of all of these colors are also provided.  These colors may be ignored
+completely on non-256-color terminals or may be misinterpreted and produce
+random behavior.  Additional attributes such as blink, italic, or bold may
+not work with the 256-color palette.
 
 There is unfortunately no way to know whether the current emulator
 supports more than eight colors, which makes the choice of colors
@@ -744,13 +755,13 @@ The recognized bright background color attributes (colors 
8 to 15) are:
 
 For 256-color terminals, the recognized foreground colors are:
 
-  ansi0 .. ansi15
+  ansi0 .. ansi255
   grey0 .. grey23
 
 plus C<rgbI<RGB>> for I<R>, I<G>, and I<B> values from 0 to 5, such as
 C<rgb000> or C<rgb515>.  Similarly, the recognized background colors are:
 
-  on_ansi0 .. on_ansi15
+  on_ansi0 .. on_ansi255
   on_grey0 .. on_grey23
 
 plus C<on_rgbI<RGB>> for I<R>, I<G>, and I<B> values from 0 to 5.
@@ -801,7 +812,9 @@ $Term::ANSIColor::EACHLINE to C<"\n"> to use this feature.
 
 uncolor() performs the opposite translation as color(), turning escape
 sequences into a list of strings corresponding to the attributes being set
-by those sequences.
+by those sequences.  uncolor() will never return C<ansi16> through
+C<ansi255>, instead preferring the C<grey> and C<rgb> names (and likewise
+for C<on_ansi16> through C<on_ansi255>).
 
 =item colorstrip(STRING[, STRING ...])
 
@@ -875,12 +888,12 @@ described above since a background color is being used.)
 If you import C<:constants256>, you can use the following constants
 directly:
 
-  ANSI0 .. ANSI15
+  ANSI0 .. ANSI255
   GREY0 .. GREY23
 
   RGBXYZ (for X, Y, and Z values from 0 to 5, like RGB000 or RGB515)
 
-  ON_ANSI0 .. ON_ANSI15
+  ON_ANSI0 .. ON_ANSI255
   ON_GREY0 .. ON_GREY23
 
   ON_RGBXYZ (for X, Y, and Z values from 0 to 5)
@@ -1122,6 +1135,10 @@ $Term::ANSIColor::AUTOLOCAL was changed to take 
precedence over
 $Term::ANSIColor::AUTORESET, rather than the other way around, in
 Term::ANSIColor 4.00, included in Perl 5.17.8.
 
+C<ansi16> through C<ansi255>, as aliases for the C<rgb> and C<grey>
+colors, and the corresponding C<on_ansi> names and C<ANSI> and C<ON_ANSI>
+constants, were added in Term::ANSIColor 4.06.
+
 =head1 RESTRICTIONS
 
 It would be nice if one could leave off the commas around the constants
@@ -1233,6 +1250,8 @@ The CPAN module L<Term::ExtendedColor> provides a 
different and more
 comprehensive interface for 256-color emulators that may be more
 convenient.  The CPAN module L<Win32::Console::ANSI> provides ANSI color
 (and other escape sequence) support in the Win32 Console environment.
+The CPAN module L<Term::Chrome> provides a different interface using
+objects and operator overloading.
 
 ECMA-048 is available on-line (at least at the time of this writing) at
 L<http://www.ecma-international.org/publications/standards/Ecma-048.htm>.
@@ -1247,7 +1266,7 @@ L<http://invisible-island.net/xterm/ctlseqs/ctlseqs.html> 
(search for
 256-color).
 
 The current version of this module is always available from its web site
-at L<http://www.eyrie.org/~eagle/software/ansicolor/>.  It is also part of
-the Perl core distribution as of 5.6.0.
+at L<https://www.eyrie.org/~eagle/software/ansicolor/>.  It is also part
+of the Perl core distribution as of 5.6.0.
 
 =cut
diff --git a/cpan/Term-ANSIColor/t/lib/Test/RRA.pm 
b/cpan/Term-ANSIColor/t/lib/Test/RRA.pm
index 5ac6eb8..bcd6532 100644
--- a/cpan/Term-ANSIColor/t/lib/Test/RRA.pm
+++ b/cpan/Term-ANSIColor/t/lib/Test/RRA.pm
@@ -13,6 +13,7 @@ use strict;
 use warnings;
 
 use Exporter;
+use File::Temp;
 use Test::More;
 
 # For Perl 5.006 compatibility.
@@ -26,12 +27,56 @@ our (@EXPORT_OK, @ISA, $VERSION);
 # consistency is good).
 BEGIN {
     @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(skip_unless_author skip_unless_automated use_prereq);
+    @EXPORT_OK = qw(
+      is_file_contents skip_unless_author skip_unless_automated use_prereq
+    );
 
     # This version should match the corresponding rra-c-util release, but with
     # two digits for the minor version, including a leading zero if necessary,
     # so that it will sort properly.
-    $VERSION = '5.11';
+    $VERSION = '6.02';
+}
+
+# Compare a string to the contents of a file, similar to the standard is()
+# function, but to show the line-based unified diff between them if they
+# differ.
+#
+# $got      - The output that we received
+# $expected - The path to the file containing the expected output
+# $message  - The message to use when reporting the test results
+#
+# Returns: undef
+#  Throws: Exception on failure to read or write files or run diff
+sub is_file_contents {
+    my ($got, $expected, $message) = @_;
+
+    # If they're equal, this is simple.
+    open(my $fh, '<', $expected) or BAIL_OUT("Cannot open $expected: $!\n");
+    my $data = do { local $/ = undef; <$fh> };
+    close($fh) or BAIL_OUT("Cannot close $expected: $!\n");
+    if ($got eq $data) {
+        is($got, $data, $message);
+        return;
+    }
+
+    # Otherwise, we show a diff, but only if we have IPC::System::Simple.
+    eval { require IPC::System::Simple };
+    if ($@) {
+        ok(0, $message);
+        return;
+    }
+
+    # They're not equal.  Write out what we got so that we can run diff.
+    my $tmp     = File::Temp->new();
+    my $tmpname = $tmp->filename;
+    print {$tmp} $got or BAIL_OUT("Cannot write to $tmpname: $!\n");
+    my @command = ('diff', '-u', $expected, $tmpname);
+    my $diff = IPC::System::Simple::capturex([0 .. 1], @command);
+    diag($diff);
+
+    # Remove the temporary file and report failure.
+    ok(0, $message);
+    return;
 }
 
 # Skip this test unless author tests are requested.  Takes a short description
@@ -225,7 +270,7 @@ SOFTWARE.
 Test::More(3), Test::RRA::Automake(3), Test::RRA::Config(3)
 
 This module is maintained in the rra-c-util package.  The current version is
-available from L<http://www.eyrie.org/~eagle/software/rra-c-util/>.
+available from L<https://www.eyrie.org/~eagle/software/rra-c-util/>.
 
 The functions to control when tests are run use environment variables defined
 by the L<Lancaster
diff --git a/cpan/Term-ANSIColor/t/module/basic256.t 
b/cpan/Term-ANSIColor/t/module/basic256.t
index a24b0ce..ae06d1a 100644
--- a/cpan/Term-ANSIColor/t/module/basic256.t
+++ b/cpan/Term-ANSIColor/t/module/basic256.t
@@ -3,7 +3,7 @@
 # Tests for 256-color support.
 #
 # Copyright 2012 Kurt Starsinic <[email protected]>
-# Copyright 2012, 2013 Russ Allbery <[email protected]>
+# Copyright 2012, 2013, 2016 Russ Allbery <[email protected]>
 #
 # This program is free software; you may redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -11,7 +11,7 @@
 use strict;
 use warnings;
 
-use Test::More tests => 92;
+use Test::More tests => 94;
 
 # Load the module.
 BEGIN {
@@ -29,7 +29,7 @@ is(color('grey0'),  "\e[38;5;232m", 'Grey 0');
 is(color('grey23'), "\e[38;5;255m", 'Grey 23');
 
 # Errors at boundary cases.
-for my $color (qw(ansi16 rgb600 rgb060 rgb006 rgb666 rgb999 rgb0000 grey24)) {
+for my $color (qw(ansi256 rgb600 rgb060 rgb006 rgb666 rgb999 rgb0000 grey24)) {
     my $output = eval { color($color) };
     is($output, undef, 'color on unknown color name fails');
     like(
@@ -49,6 +49,7 @@ for my $color (qw(ansi0 ansi15 rgb000 rgb555 grey0 grey23)) {
 is_deeply([uncolor('38;5;0')],        ['ansi0'],    'uncolor of ansi0');
 is_deeply([uncolor("\e[38;5;231m")],  ['rgb555'],   'uncolor of rgb555');
 is_deeply([uncolor("\e[48;05;001m")], ['on_ansi1'], 'uncolor with leading 0s');
+is_deeply([uncolor("\e[38;5;233")],   ['grey1'],    'uncolor of grey1');
 
 # An invalid 256-color code should report an error on the part that makes it
 # invalid.  Check truncated codes (should report on the 38 or 48), codes with
@@ -79,12 +80,13 @@ while (my ($escape, $invalid) = each %uncolor_tests) {
 }
 
 # Test all the variations of a few different constants.
-is((ANSI0 't'),  "\e[38;5;0mt",   'Basic constant works for ANSI0');
-is((ANSI15 't'), "\e[38;5;15mt",  '...and for ANSI15');
-is((RGB000 't'), "\e[38;5;16mt",  '...and for RGB000');
-is((RGB555 't'), "\e[38;5;231mt", '...and for RGB555');
-is((GREY0 't'),  "\e[38;5;232mt", '...and for GREY0');
-is((GREY23 't'), "\e[38;5;255mt", '...and for GREY23');
+is((ANSI0 't'),   "\e[38;5;0mt",   'Basic constant works for ANSI0');
+is((ANSI15 't'),  "\e[38;5;15mt",  '...and for ANSI15');
+is((ANSI255 't'), "\e[38;5;255mt", '...and for ANSI255');
+is((RGB000 't'),  "\e[38;5;16mt",  '...and for RGB000');
+is((RGB555 't'),  "\e[38;5;231mt", '...and for RGB555');
+is((GREY0 't'),   "\e[38;5;232mt", '...and for GREY0');
+is((GREY23 't'),  "\e[38;5;255mt", '...and for GREY23');
 
 # Do the same for disabled colors.
 local $ENV{ANSI_COLORS_DISABLED} = 1;
diff --git a/cpan/Test-Simple/lib/Test/Builder.pm 
b/cpan/Test-Simple/lib/Test/Builder.pm
index d3febbc..a10c19f 100644
--- a/cpan/Test-Simple/lib/Test/Builder.pm
+++ b/cpan/Test-Simple/lib/Test/Builder.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 BEGIN {
     if( $] < 5.008 ) {
@@ -339,7 +339,7 @@ sub subtest {
         $st_ctx->diag('No tests run!');
     }
 
-    $child->finalize($ok);
+    $child->finalize($st_ctx->trace);
 
     $ctx->release;
 
@@ -1146,7 +1146,7 @@ BEGIN {
 
             my $ctx = $self->ctx;
             my $format = $ctx->hub->format;
-            unless ($format && $format->isa('Test2::Formatter::TAP') && 
$format->can($set)) {
+            unless ($format && $format->can($set)) {
                 warn "The current formatter does not support '$method'" if 
$format;
                 $ctx->release;
                 return
diff --git a/cpan/Test-Simple/lib/Test/Builder/Formatter.pm 
b/cpan/Test-Simple/lib/Test/Builder/Formatter.pm
index 8aa7e2c..e4051a5 100644
--- a/cpan/Test-Simple/lib/Test/Builder/Formatter.pm
+++ b/cpan/Test-Simple/lib/Test/Builder/Formatter.pm
@@ -2,7 +2,7 @@ package Test::Builder::Formatter;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 BEGIN { require Test2::Formatter::TAP; our @ISA = qw(Test2::Formatter::TAP) }
 
diff --git a/cpan/Test-Simple/lib/Test/Builder/Module.pm 
b/cpan/Test-Simple/lib/Test/Builder/Module.pm
index fe35da6..0bf0b08 100644
--- a/cpan/Test-Simple/lib/Test/Builder/Module.pm
+++ b/cpan/Test-Simple/lib/Test/Builder/Module.pm
@@ -7,7 +7,7 @@ use Test::Builder;
 require Exporter;
 our @ISA = qw(Exporter);
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 =head1 NAME
diff --git a/cpan/Test-Simple/lib/Test/Builder/Tester.pm 
b/cpan/Test-Simple/lib/Test/Builder/Tester.pm
index 716d521..680adf2 100644
--- a/cpan/Test-Simple/lib/Test/Builder/Tester.pm
+++ b/cpan/Test-Simple/lib/Test/Builder/Tester.pm
@@ -1,7 +1,7 @@
 package Test::Builder::Tester;
 
 use strict;
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 use Test::Builder;
 use Symbol;
diff --git a/cpan/Test-Simple/lib/Test/Builder/Tester/Color.pm 
b/cpan/Test-Simple/lib/Test/Builder/Tester/Color.pm
index 4ab8670..c67378b 100644
--- a/cpan/Test-Simple/lib/Test/Builder/Tester/Color.pm
+++ b/cpan/Test-Simple/lib/Test/Builder/Tester/Color.pm
@@ -1,7 +1,7 @@
 package Test::Builder::Tester::Color;
 
 use strict;
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 require Test::Builder::Tester;
 
diff --git a/cpan/Test-Simple/lib/Test/Builder/TodoDiag.pm 
b/cpan/Test-Simple/lib/Test/Builder/TodoDiag.pm
index 7da9339..2ae2626 100644
--- a/cpan/Test-Simple/lib/Test/Builder/TodoDiag.pm
+++ b/cpan/Test-Simple/lib/Test/Builder/TodoDiag.pm
@@ -2,7 +2,7 @@ package Test::Builder::TodoDiag;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 BEGIN { require Test2::Event::Diag; our @ISA = qw(Test2::Event::Diag) }
 
diff --git a/cpan/Test-Simple/lib/Test/More.pm 
b/cpan/Test-Simple/lib/Test/More.pm
index 6239877..0a0bfbe 100644
--- a/cpan/Test-Simple/lib/Test/More.pm
+++ b/cpan/Test-Simple/lib/Test/More.pm
@@ -17,7 +17,7 @@ sub _carp {
     return warn @_, " at $file line $line\n";
 }
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
diff --git a/cpan/Test-Simple/lib/Test/Simple.pm 
b/cpan/Test-Simple/lib/Test/Simple.pm
index b0261f8..3910d3c 100644
--- a/cpan/Test-Simple/lib/Test/Simple.pm
+++ b/cpan/Test-Simple/lib/Test/Simple.pm
@@ -4,7 +4,7 @@ use 5.006;
 
 use strict;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
diff --git a/cpan/Test-Simple/lib/Test/Tester.pm 
b/cpan/Test-Simple/lib/Test/Tester.pm
index 96c42e1..18f377c 100644
--- a/cpan/Test-Simple/lib/Test/Tester.pm
+++ b/cpan/Test-Simple/lib/Test/Tester.pm
@@ -18,7 +18,7 @@ require Exporter;
 
 use vars qw( @ISA @EXPORT );
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 @EXPORT = qw( run_tests check_tests check_test cmp_results show_space );
 @ISA = qw( Exporter );
diff --git a/cpan/Test-Simple/lib/Test/Tester/Capture.pm 
b/cpan/Test-Simple/lib/Test/Tester/Capture.pm
index eeb0d2a..d02230f 100644
--- a/cpan/Test-Simple/lib/Test/Tester/Capture.pm
+++ b/cpan/Test-Simple/lib/Test/Tester/Capture.pm
@@ -2,7 +2,7 @@ use strict;
 
 package Test::Tester::Capture;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test::Builder;
diff --git a/cpan/Test-Simple/lib/Test/Tester/CaptureRunner.pm 
b/cpan/Test-Simple/lib/Test/Tester/CaptureRunner.pm
index d768b9b..ae03fcf 100644
--- a/cpan/Test-Simple/lib/Test/Tester/CaptureRunner.pm
+++ b/cpan/Test-Simple/lib/Test/Tester/CaptureRunner.pm
@@ -3,7 +3,7 @@ use strict;
 
 package Test::Tester::CaptureRunner;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test::Tester::Capture;
diff --git a/cpan/Test-Simple/lib/Test/Tester/Delegate.pm 
b/cpan/Test-Simple/lib/Test/Tester/Delegate.pm
index 91cee4c..e043092 100644
--- a/cpan/Test-Simple/lib/Test/Tester/Delegate.pm
+++ b/cpan/Test-Simple/lib/Test/Tester/Delegate.pm
@@ -3,7 +3,7 @@ use warnings;
 
 package Test::Tester::Delegate;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use vars '$AUTOLOAD';
diff --git a/cpan/Test-Simple/lib/Test/use/ok.pm 
b/cpan/Test-Simple/lib/Test/use/ok.pm
index 5d0591f..a56f2d1 100644
--- a/cpan/Test-Simple/lib/Test/use/ok.pm
+++ b/cpan/Test-Simple/lib/Test/use/ok.pm
@@ -1,7 +1,7 @@
 package Test::use::ok;
 use 5.005;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 __END__
diff --git a/cpan/Test-Simple/lib/Test2.pm b/cpan/Test-Simple/lib/Test2.pm
index 29f8411..7f365e1 100644
--- a/cpan/Test-Simple/lib/Test2.pm
+++ b/cpan/Test-Simple/lib/Test2.pm
@@ -2,7 +2,7 @@ package Test2;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 1;
diff --git a/cpan/Test-Simple/lib/Test2/API.pm 
b/cpan/Test-Simple/lib/Test2/API.pm
index ba25944..98bcb1f 100644
--- a/cpan/Test-Simple/lib/Test2/API.pm
+++ b/cpan/Test-Simple/lib/Test2/API.pm
@@ -2,7 +2,7 @@ package Test2::API;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 my $INST;
diff --git a/cpan/Test-Simple/lib/Test2/API/Breakage.pm 
b/cpan/Test-Simple/lib/Test2/API/Breakage.pm
index 7b21cca..8667d85 100644
--- a/cpan/Test-Simple/lib/Test2/API/Breakage.pm
+++ b/cpan/Test-Simple/lib/Test2/API/Breakage.pm
@@ -2,7 +2,7 @@ package Test2::API::Breakage;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::Util qw/pkg_to_file/;
diff --git a/cpan/Test-Simple/lib/Test2/API/Context.pm 
b/cpan/Test-Simple/lib/Test2/API/Context.pm
index c4e1ece..27da02a 100644
--- a/cpan/Test-Simple/lib/Test2/API/Context.pm
+++ b/cpan/Test-Simple/lib/Test2/API/Context.pm
@@ -2,7 +2,7 @@ package Test2::API::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Carp qw/confess croak longmess/;
diff --git a/cpan/Test-Simple/lib/Test2/API/Instance.pm 
b/cpan/Test-Simple/lib/Test2/API/Instance.pm
index 556cad1..567d54c 100644
--- a/cpan/Test-Simple/lib/Test2/API/Instance.pm
+++ b/cpan/Test-Simple/lib/Test2/API/Instance.pm
@@ -2,7 +2,7 @@ package Test2::API::Instance;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 our @CARP_NOT = qw/Test2::API Test2::API::Instance Test2::IPC::Driver 
Test2::Formatter/;
diff --git a/cpan/Test-Simple/lib/Test2/API/Stack.pm 
b/cpan/Test-Simple/lib/Test2/API/Stack.pm
index 6db9f57..438f6c0 100644
--- a/cpan/Test-Simple/lib/Test2/API/Stack.pm
+++ b/cpan/Test-Simple/lib/Test2/API/Stack.pm
@@ -2,7 +2,7 @@ package Test2::API::Stack;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::Hub();
diff --git a/cpan/Test-Simple/lib/Test2/Event.pm 
b/cpan/Test-Simple/lib/Test2/Event.pm
index a0aa619..dedf7c2 100644
--- a/cpan/Test-Simple/lib/Test2/Event.pm
+++ b/cpan/Test-Simple/lib/Test2/Event.pm
@@ -2,7 +2,7 @@ package Test2::Event;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::Util::HashBase qw/trace nested in_subtest subtest_id/;
diff --git a/cpan/Test-Simple/lib/Test2/Event/Bail.pm 
b/cpan/Test-Simple/lib/Test2/Event/Bail.pm
index 06c94ce..f1fdb2b 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Bail.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Bail.pm
@@ -2,7 +2,7 @@ package Test2::Event::Bail;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Diag.pm 
b/cpan/Test-Simple/lib/Test2/Event/Diag.pm
index 08b8621..af2e0b5 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Diag.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Diag.pm
@@ -2,7 +2,7 @@ package Test2::Event::Diag;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Exception.pm 
b/cpan/Test-Simple/lib/Test2/Event/Exception.pm
index 4f7c7c5..5050494 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Exception.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Exception.pm
@@ -2,7 +2,7 @@ package Test2::Event::Exception;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Generic.pm 
b/cpan/Test-Simple/lib/Test2/Event/Generic.pm
index ff47ced..0ae200e 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Generic.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Generic.pm
@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
 use Test2::Util::HashBase;
diff --git a/cpan/Test-Simple/lib/Test2/Event/Info.pm 
b/cpan/Test-Simple/lib/Test2/Event/Info.pm
index 7b1db5f..f78fa35 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Info.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Info.pm
@@ -4,7 +4,7 @@ use warnings;
 
 use Scalar::Util qw/blessed/;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
 use Test2::Util::HashBase qw/diagnostics renderer/;
diff --git a/cpan/Test-Simple/lib/Test2/Event/Note.pm 
b/cpan/Test-Simple/lib/Test2/Event/Note.pm
index d0df97d..bff3c7b 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Note.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Note.pm
@@ -2,7 +2,7 @@ package Test2::Event::Note;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Ok.pm 
b/cpan/Test-Simple/lib/Test2/Event/Ok.pm
index d0cf32f..b372fd1 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Ok.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Ok.pm
@@ -2,7 +2,7 @@ package Test2::Event::Ok;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Plan.pm 
b/cpan/Test-Simple/lib/Test2/Event/Plan.pm
index 1986f59..2ce3315 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Plan.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Plan.pm
@@ -2,7 +2,7 @@ package Test2::Event::Plan;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Skip.pm 
b/cpan/Test-Simple/lib/Test2/Event/Skip.pm
index dedb06d..7d5c3d9 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Skip.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Skip.pm
@@ -2,7 +2,7 @@ package Test2::Event::Skip;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event::Ok; our @ISA = qw(Test2::Event::Ok) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Subtest.pm 
b/cpan/Test-Simple/lib/Test2/Event/Subtest.pm
index f0b026e..4792280 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Subtest.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Subtest.pm
@@ -2,7 +2,7 @@ package Test2::Event::Subtest;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event::Ok; our @ISA = qw(Test2::Event::Ok) }
diff --git a/cpan/Test-Simple/lib/Test2/Event/Waiting.pm 
b/cpan/Test-Simple/lib/Test2/Event/Waiting.pm
index 2baa533..304af72 100644
--- a/cpan/Test-Simple/lib/Test2/Event/Waiting.pm
+++ b/cpan/Test-Simple/lib/Test2/Event/Waiting.pm
@@ -2,7 +2,7 @@ package Test2::Event::Waiting;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
diff --git a/cpan/Test-Simple/lib/Test2/Formatter.pm 
b/cpan/Test-Simple/lib/Test2/Formatter.pm
index f3536c8..d005594 100644
--- a/cpan/Test-Simple/lib/Test2/Formatter.pm
+++ b/cpan/Test-Simple/lib/Test2/Formatter.pm
@@ -2,7 +2,7 @@ package Test2::Formatter;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 my %ADDED;
@@ -16,6 +16,10 @@ sub import {
 
 sub hide_buffered { 1 }
 
+sub terminate { }
+
+sub finalize { }
+
 1;
 
 __END__
@@ -48,6 +52,10 @@ A formatter is any package or object with a C<write($event, 
$num)> method.
 
     sub hide_buffered { 1 }
 
+    sub terminate { }
+
+    sub finalize { }
+
     1;
 
 The C<write> method is a method, so it either gets a class or instance. The two
@@ -60,6 +68,32 @@ The C<hide_buffered()> method must return a boolean. This is 
used to tell
 buffered subtests whether or not to send it events as they are being buffered.
 See L<Test2::API/"run_subtest(...)"> for more information.
 
+The C<terminate> and C<finalize> methods are optional methods called that you
+can implement if the format you're generating needs to handle these cases, for
+example if you are generating XML and need close open tags.
+
+The C<terminate> method is called when an event's C<terminate> method returns
+true, for example when a L<Test2::Event::Plan> has a C<'skip_all'> plan, or
+when a L<Test2::Event::Bail> event is sent. The C<terminate> method is passed
+a single argument, the L<Test2::Event> object which triggered the terminate.
+
+The C<finalize> method is always the last thing called on the formatter, I<<
+except when C<terminate> is called for a Bail event >>. It is passed the
+following arguments:
+
+=over 4
+
+=item * The number of tests that were planned
+
+=item * The number of tests actually seen
+
+=item * The number of tests which failed
+
+=item * A boolean indicating whether or not the test suite passed
+
+=item * A boolean indicating whether or not this call is for a subtest
+
+=back
 
 =head1 SOURCE
 
diff --git a/cpan/Test-Simple/lib/Test2/Formatter/TAP.pm 
b/cpan/Test-Simple/lib/Test2/Formatter/TAP.pm
index 93f53f0..3c2cce8 100644
--- a/cpan/Test-Simple/lib/Test2/Formatter/TAP.pm
+++ b/cpan/Test-Simple/lib/Test2/Formatter/TAP.pm
@@ -3,7 +3,7 @@ use strict;
 use warnings;
 require PerlIO;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::Util::HashBase qw{
diff --git a/cpan/Test-Simple/lib/Test2/Hub.pm 
b/cpan/Test-Simple/lib/Test2/Hub.pm
index edc873b..d15912d 100644
--- a/cpan/Test-Simple/lib/Test2/Hub.pm
+++ b/cpan/Test-Simple/lib/Test2/Hub.pm
@@ -2,7 +2,7 @@ package Test2::Hub;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Carp qw/carp croak confess/;
@@ -54,6 +54,8 @@ sub init {
     }
 }
 
+sub is_subtest { 0 }
+
 sub reset_state {
     my $self = shift;
 
@@ -300,7 +302,10 @@ sub process {
     return $e if $is_ok || $no_fail;
 
     my $code = $e->terminate;
-    $self->terminate($code, $e) if defined $code;
+    if (defined $code) {
+        $self->{+_FORMATTER}->terminate($e) if $self->{+_FORMATTER};
+        $self->terminate($code, $e);
+    }
 
     return $e;
 }
@@ -332,8 +337,11 @@ sub finalize {
     my $failed = $self->{+FAILED};
     my $active = $self->{+ACTIVE};
 
-    # return if NOTHING was done.
-    return unless $active || $do_plan || defined($plan) || $count || $failed;
+       # return if NOTHING was done.
+       unless ($active || $do_plan || defined($plan) || $count || $failed) {
+               $self->{+_FORMATTER}->finalize($plan, $count, $failed, 0, 
$self->is_subtest) if $self->{+_FORMATTER};
+               return;
+       }
 
     unless ($self->{+ENDED}) {
         if ($self->{+_FOLLOW_UPS}) {
@@ -369,7 +377,11 @@ Second End: $sfile line $sline
     }
 
     $self->{+ENDED} = $frame;
-    $self->is_passing(); # Generate the final boolean.
+    my $pass = $self->is_passing(); # Generate the final boolean.
+
+       $self->{+_FORMATTER}->finalize($plan, $count, $failed, $pass, 
$self->is_subtest) if $self->{+_FORMATTER};
+
+    return $pass;
 }
 
 sub is_passing {
diff --git a/cpan/Test-Simple/lib/Test2/Hub/Interceptor.pm 
b/cpan/Test-Simple/lib/Test2/Hub/Interceptor.pm
index 31bdd14..5d211d2 100644
--- a/cpan/Test-Simple/lib/Test2/Hub/Interceptor.pm
+++ b/cpan/Test-Simple/lib/Test2/Hub/Interceptor.pm
@@ -2,7 +2,7 @@ package Test2::Hub::Interceptor;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::Hub::Interceptor::Terminator();
diff --git a/cpan/Test-Simple/lib/Test2/Hub/Interceptor/Terminator.pm 
b/cpan/Test-Simple/lib/Test2/Hub/Interceptor/Terminator.pm
index 95fb1f1..bbfa983 100644
--- a/cpan/Test-Simple/lib/Test2/Hub/Interceptor/Terminator.pm
+++ b/cpan/Test-Simple/lib/Test2/Hub/Interceptor/Terminator.pm
@@ -2,7 +2,7 @@ package Test2::Hub::Interceptor::Terminator;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 1;
diff --git a/cpan/Test-Simple/lib/Test2/Hub/Subtest.pm 
b/cpan/Test-Simple/lib/Test2/Hub/Subtest.pm
index 88b079a..2da6968 100644
--- a/cpan/Test-Simple/lib/Test2/Hub/Subtest.pm
+++ b/cpan/Test-Simple/lib/Test2/Hub/Subtest.pm
@@ -2,7 +2,7 @@ package Test2::Hub::Subtest;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::Hub; our @ISA = qw(Test2::Hub) }
@@ -16,6 +16,8 @@ sub init {
     $self->{+ID} ||= join "-", $$, get_tid, $ID++;
 }
 
+sub is_subtest { 1 }
+
 sub process {
     my $self = shift;
     my ($e) = @_;
diff --git a/cpan/Test-Simple/lib/Test2/IPC.pm 
b/cpan/Test-Simple/lib/Test2/IPC.pm
index 620f1f8..5c034e3 100644
--- a/cpan/Test-Simple/lib/Test2/IPC.pm
+++ b/cpan/Test-Simple/lib/Test2/IPC.pm
@@ -2,7 +2,7 @@ package Test2::IPC;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::API::Instance;
diff --git a/cpan/Test-Simple/lib/Test2/IPC/Driver.pm 
b/cpan/Test-Simple/lib/Test2/IPC/Driver.pm
index 6e9d0c3..32d1333 100644
--- a/cpan/Test-Simple/lib/Test2/IPC/Driver.pm
+++ b/cpan/Test-Simple/lib/Test2/IPC/Driver.pm
@@ -2,7 +2,7 @@ package Test2::IPC::Driver;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Carp qw/confess longmess/;
diff --git a/cpan/Test-Simple/lib/Test2/IPC/Driver/Files.pm 
b/cpan/Test-Simple/lib/Test2/IPC/Driver/Files.pm
index 5fddaca..696bda9 100644
--- a/cpan/Test-Simple/lib/Test2/IPC/Driver/Files.pm
+++ b/cpan/Test-Simple/lib/Test2/IPC/Driver/Files.pm
@@ -2,7 +2,7 @@ package Test2::IPC::Driver::Files;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 BEGIN { require Test2::IPC::Driver; our @ISA = qw(Test2::IPC::Driver) }
diff --git a/cpan/Test-Simple/lib/Test2/Util.pm 
b/cpan/Test-Simple/lib/Test2/Util.pm
index 9b810c6..070c574 100644
--- a/cpan/Test-Simple/lib/Test2/Util.pm
+++ b/cpan/Test-Simple/lib/Test2/Util.pm
@@ -2,7 +2,7 @@ package Test2::Util;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Config qw/%Config/;
diff --git a/cpan/Test-Simple/lib/Test2/Util/ExternalMeta.pm 
b/cpan/Test-Simple/lib/Test2/Util/ExternalMeta.pm
index e99b360..0d73fbe 100644
--- a/cpan/Test-Simple/lib/Test2/Util/ExternalMeta.pm
+++ b/cpan/Test-Simple/lib/Test2/Util/ExternalMeta.pm
@@ -2,7 +2,7 @@ package Test2::Util::ExternalMeta;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Carp qw/croak/;
diff --git a/cpan/Test-Simple/lib/Test2/Util/HashBase.pm 
b/cpan/Test-Simple/lib/Test2/Util/HashBase.pm
index 6594c52..0a40191 100644
--- a/cpan/Test-Simple/lib/Test2/Util/HashBase.pm
+++ b/cpan/Test-Simple/lib/Test2/Util/HashBase.pm
@@ -2,7 +2,7 @@ package Test2::Util::HashBase;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 require Carp;
diff --git a/cpan/Test-Simple/lib/Test2/Util/Trace.pm 
b/cpan/Test-Simple/lib/Test2/Util/Trace.pm
index 189fe5f..34be24f 100644
--- a/cpan/Test-Simple/lib/Test2/Util/Trace.pm
+++ b/cpan/Test-Simple/lib/Test2/Util/Trace.pm
@@ -2,7 +2,7 @@ package Test2::Util::Trace;
 use strict;
 use warnings;
 
-our $VERSION = '1.302059';
+our $VERSION = '1.302062';
 
 
 use Test2::Util qw/get_tid/;
diff --git a/cpan/Test-Simple/lib/ok.pm b/cpan/Test-Simple/lib/ok.pm
index 4a42d75..4c5f9d1 100644
--- a/cpan/Test-Simple/lib/ok.pm
+++ b/cpan/Test-Simple/lib/ok.pm
@@ -1,5 +1,5 @@
 package ok;
-$ok::VERSION = '1.302059';
+$ok::VERSION = '1.302062';
 
 use strict;
 use Test::More ();
diff --git a/cpan/Test-Simple/t/Legacy/missing.t 
b/cpan/Test-Simple/t/Legacy/missing.t
index 3996b6d..3b8f1fa 100644
--- a/cpan/Test-Simple/t/Legacy/missing.t
+++ b/cpan/Test-Simple/t/Legacy/missing.t
@@ -1,3 +1,4 @@
+# HARNESS-NO-PRELOAD
 BEGIN {
     if( $ENV{PERL_CORE} ) {
         chdir 't';
diff --git a/cpan/Test-Simple/t/Test2/behavior/Formatter.t 
b/cpan/Test-Simple/t/Test2/behavior/Formatter.t
new file mode 100644
index 0000000..01eebc6
--- /dev/null
+++ b/cpan/Test-Simple/t/Test2/behavior/Formatter.t
@@ -0,0 +1,84 @@
+use strict;
+use warnings;
+
+BEGIN { require "t/tools.pl" }
+
+use Test2::API qw/intercept run_subtest test2_stack/;
+use Test2::Event::Bail;
+
+{
+
+       package Formatter::Subclass;
+       use parent 'Test2::Formatter';
+       use Test2::Util::HashBase qw{f t};
+
+    sub init {
+        my $self = shift;
+        $self->{+F} = [];
+        $self->{+T} = [];
+    }
+
+       sub write         { }
+       sub hide_buffered { 1 }
+
+       sub terminate {
+               my $s = shift;
+               push @{$s->{+T}}, [@_];
+       }
+
+       sub finalize {
+               my $s = shift;
+               push @{$s->{+F}}, [@_];
+       }
+}
+
+{
+       my $f = Formatter::Subclass->new;
+       intercept {
+               my $hub = test2_stack->top;
+               $hub->format($f);
+               is(1, 1, 'test event 1');
+               is(2, 2, 'test event 2');
+               is(3, 2, 'test event 3');
+               done_testing;
+       };
+
+       is(scalar @{$f->f}, 1, 'finalize method was called on formatter');
+       is_deeply(
+               $f->f->[0],
+               [3, 3, 1, 0, 0],
+               'finalize method received expected arguments'
+       );
+
+       ok(!@{$f->t}, 'terminate method was not called on formatter');
+}
+
+{
+       my $f = Formatter::Subclass->new;
+
+       intercept {
+               my $hub = test2_stack->top;
+               $hub->format($f);
+               $hub->send(Test2::Event::Bail->new(reason => 'everything is 
terrible'));
+               done_testing;
+       };
+
+       is(scalar @{$f->t}, 1, 'terminate method was called because of bail 
event');
+       ok(!@{$f->f}, 'finalize method was not called on formatter');
+}
+
+{
+       my $f = Formatter::Subclass->new;
+
+       intercept {
+               my $hub = test2_stack->top;
+               $hub->format($f);
+               $hub->send(Test2::Event::Plan->new(directive => 'skip_all', 
reason => 'Skipping all the tests'));
+               done_testing;
+       };
+
+       is(scalar @{$f->t}, 1, 'terminate method was called because of plan 
skip_all event');
+       ok(!@{$f->f}, 'finalize method was not called on formatter');
+}
+
+done_testing;
diff --git a/cpan/Test-Simple/t/Test2/behavior/Subtest_buffer_formatter.t 
b/cpan/Test-Simple/t/Test2/behavior/Subtest_buffer_formatter.t
index 6aa0ffb..2fc58ef 100644
--- a/cpan/Test-Simple/t/Test2/behavior/Subtest_buffer_formatter.t
+++ b/cpan/Test-Simple/t/Test2/behavior/Subtest_buffer_formatter.t
@@ -8,14 +8,20 @@ use Test2::API qw/run_subtest intercept test2_stack/;
 {
     package Formatter::Hide;
     sub write { }
-    sub hide_buffered { 1 };
+    sub hide_buffered { 1 }
+    sub terminate { }
+    sub finalize { }
 
     package Formatter::Show;
     sub write { }
-    sub hide_buffered { 0 };
+    sub hide_buffered { 0 }
+    sub terminate { }
+    sub finalize { }
 
     package Formatter::NA;
     sub write { }
+    sub terminate { }
+    sub finalize { }
 }
 
 my %HAS_FORMATTER;
diff --git a/cpan/Test-Simple/t/Test2/behavior/no_load_api.t 
b/cpan/Test-Simple/t/Test2/behavior/no_load_api.t
index eab0da8..8bf54c9 100644
--- a/cpan/Test-Simple/t/Test2/behavior/no_load_api.t
+++ b/cpan/Test-Simple/t/Test2/behavior/no_load_api.t
@@ -1,3 +1,4 @@
+# HARNESS-NO-PRELOAD
 use strict;
 use warnings;
 use Data::Dumper;
diff --git a/cpan/Unicode-Collate/Collate.pm b/cpan/Unicode-Collate/Collate.pm
index 493c281..ea2f946 100644
--- a/cpan/Unicode-Collate/Collate.pm
+++ b/cpan/Unicode-Collate/Collate.pm
@@ -17,7 +17,7 @@ use File::Spec;
 
 no warnings 'utf8';
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 our $PACKAGE = __PACKAGE__;
 
 ### begin XS only ###
@@ -89,9 +89,9 @@ my $DefaultRearrange = [ 0x0E40..0x0E44, 0x0EC0..0x0EC4 ];
 my $HighestVCE = pack(VCE_TEMPLATE, 0, 0xFFFE, 0x20, 0x5, 0xFFFF);
 my $minimalVCE = pack(VCE_TEMPLATE, 0,      1, 0x20, 0x5, 0xFFFE);
 
-sub UCA_Version { "30" }
+sub UCA_Version { "32" }
 
-sub Base_Unicode_Version { "7.0.0" }
+sub Base_Unicode_Version { "8.0.0" }
 
 ######
 
@@ -189,6 +189,7 @@ my %DerivCode = (
    26 => \&_derivCE_24, # 26 == 24
    28 => \&_derivCE_24, # 28 == 24
    30 => \&_derivCE_24, # 30 == 24
+   32 => \&_derivCE_32,
 );
 
 sub checkCollator {
@@ -1097,7 +1098,7 @@ If the revision (previously "tracking version") number of 
UCA is given,
 behavior of that revision is emulated on collating.
 If omitted, the return value of C<UCA_Version()> is used.
 
-The following revisions are supported.  The default is 30.
+The following revisions are supported.  The default is 32.
 
      UCA       Unicode Standard         DUCET (@version)
    -------------------------------------------------------
@@ -1113,6 +1114,7 @@ The following revisions are supported.  The default is 30.
      26             6.2.0               6.2.0 (6.2.0)
      28             6.3.0               6.3.0 (6.3.0)
      30             7.0.0               7.0.0 (7.0.0)
+     32             8.0.0               8.0.0 (8.0.0)
 
 * See below C<long_contraction> with C<UCA_Version> 22 and 24.
 
@@ -1451,12 +1453,14 @@ those in the CJK Unified Ideographs Extension A etc.
     U+4E00..U+9FBB if UCA_Version is 14 or 16.
     U+4E00..U+9FC3 if UCA_Version is 18.
     U+4E00..U+9FCB if UCA_Version is 20 or 22.
-    U+4E00..U+9FCC if UCA_Version is 24 or later.
+    U+4E00..U+9FCC if UCA_Version is 24 to 30.
+    U+4E00..U+9FD5 if UCA_Version is 32.
 
     In the CJK Unified Ideographs Extension blocks:
     Ext.A (U+3400..U+4DB5) and Ext.B (U+20000..U+2A6D6) in any UCA_Version.
     Ext.C (U+2A700..U+2B734) if UCA_Version is 20 or later.
     Ext.D (U+2B740..U+2B81D) if UCA_Version is 22 or later.
+    Ext.E (U+2B820..U+2CEA1) if UCA_Version is 32.
 
 Through C<overrideCJK>, ordering of CJK unified ideographs (including
 extensions) can be overridden.
@@ -1660,7 +1664,7 @@ An example for Russian and some languages using the 
Cyrillic script:
 
 where 0x0400 stands for C<U+0400>, CYRILLIC CAPITAL LETTER IE WITH GRAVE.
 
-B<NOTE>: Contractions via C<entry> are not be suppressed.
+B<NOTE>: Contractions via C<entry> will not be suppressed.
 
 =item table
 
@@ -2078,16 +2082,16 @@ B<Unicode::Normalize is required to try The Conformance 
Test.>
 =head1 AUTHOR, COPYRIGHT AND LICENSE
 
 The Unicode::Collate module for perl was written by SADAHIRO Tomoyuki,
-<[email protected]>. This module is Copyright(C) 2001-2014,
+<[email protected]>. This module is Copyright(C) 2001-2016,
 SADAHIRO Tomoyuki. Japan. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 The file Unicode/Collate/allkeys.txt was copied verbatim
-from L<http://www.unicode.org/Public/UCA/6.3.0/allkeys.txt>.
-For this file, Copyright (c) 2001-2012 Unicode, Inc.
-Distributed under the Terms of Use in L<http://www.unicode.org/copyright.html>.
+from L<http://www.unicode.org/Public/UCA/8.0.0/allkeys.txt>.
+For this file, Copyright (c) 2001-2015 Unicode, Inc.; distributed
+under the Terms of Use in L<http://www.unicode.org/terms_of_use.html>
 
 =head1 SEE ALSO
 
diff --git a/cpan/Unicode-Collate/Collate.xs b/cpan/Unicode-Collate/Collate.xs
index 6adcbeb..32d1c23 100644
--- a/cpan/Unicode-Collate/Collate.xs
+++ b/cpan/Unicode-Collate/Collate.xs
@@ -56,6 +56,7 @@
 #define CJK_UidF51    (0x9FC3)
 #define CJK_UidF52    (0x9FCB)
 #define CJK_UidF61    (0x9FCC)
+#define CJK_UidF80    (0x9FD5)
 #define CJK_ExtAIni   (0x3400) /* Unicode 3.0 */
 #define CJK_ExtAFin   (0x4DB5) /* Unicode 3.0 */
 #define CJK_ExtBIni  (0x20000) /* Unicode 3.1 */
@@ -64,6 +65,8 @@
 #define CJK_ExtCFin  (0x2B734) /* Unicode 5.2 */
 #define CJK_ExtDIni  (0x2B740) /* Unicode 6.0 */
 #define CJK_ExtDFin  (0x2B81D) /* Unicode 6.0 */
+#define CJK_ExtEIni  (0x2B820) /* Unicode 8.0 */
+#define CJK_ExtEFin  (0x2CEA1) /* Unicode 8.0 */
 
 #define CJK_CompIni  (0xFA0E)
 #define CJK_CompFin  (0xFA29)
@@ -266,6 +269,7 @@ _derivCE_9 (code)
     _derivCE_20 = 3
     _derivCE_22 = 4
     _derivCE_24 = 5
+    _derivCE_32 = 6
   PREINIT:
     UV base, aaaa, bbbb;
     U8 a[VCE_Length + 1] = "\x00\x00\x00\x00\x00\x00\x00\x00\x00";
@@ -276,7 +280,8 @@ _derivCE_9 (code)
        if (codeRange(CJK_CompIni, CJK_CompFin))
            basic_unified = (bool)UnifiedCompat[code - CJK_CompIni];
        else
-           basic_unified = (ix >= 5 ? (code <= CJK_UidF61) :
+           basic_unified = (ix >= 6 ? (code <= CJK_UidF80) :
+                            ix == 5 ? (code <= CJK_UidF61) :
                             ix >= 3 ? (code <= CJK_UidF52) :
                             ix == 2 ? (code <= CJK_UidF51) :
                             ix == 1 ? (code <= CJK_UidF41) :
@@ -290,7 +295,9 @@ _derivCE_9 (code)
                ||
            (ix >= 3 && codeRange(CJK_ExtCIni, CJK_ExtCFin))
                ||
-           (ix >= 4 && codeRange(CJK_ExtDIni, CJK_ExtDFin)))
+           (ix >= 4 && codeRange(CJK_ExtDIni, CJK_ExtDFin))
+               ||
+           (ix >= 6 && codeRange(CJK_ExtEIni, CJK_ExtEFin)))
            ? 0xFB80   /* CJK ext. */
            : 0xFBC0;  /* others */
     aaaa =  base + (code >> 15);
@@ -355,7 +362,8 @@ _isUIdeo (code, uca_vers)
        if (codeRange(CJK_CompIni, CJK_CompFin))
            basic_unified = (bool)UnifiedCompat[code - CJK_CompIni];
        else
-           basic_unified = (uca_vers >= 24 ? (code <= CJK_UidF61) :
+           basic_unified = (uca_vers >= 32 ? (code <= CJK_UidF80) :
+                            uca_vers >= 24 ? (code <= CJK_UidF61) :
                             uca_vers >= 20 ? (code <= CJK_UidF52) :
                             uca_vers >= 18 ? (code <= CJK_UidF51) :
                             uca_vers >= 14 ? (code <= CJK_UidF41) :
@@ -371,6 +379,8 @@ _isUIdeo (code, uca_vers)
        (uca_vers >= 20 && codeRange(CJK_ExtCIni, CJK_ExtCFin))
                ||
        (uca_vers >= 22 && codeRange(CJK_ExtDIni, CJK_ExtDFin))
+               ||
+       (uca_vers >= 32 && codeRange(CJK_ExtEIni, CJK_ExtEFin))
     );
 OUTPUT:
     RETVAL
diff --git a/cpan/Unicode-Collate/Collate/CJK/Big5.pm 
b/cpan/Unicode-Collate/Collate/CJK/Big5.pm
index 6399997..5fd6d84 100644
--- a/cpan/Unicode-Collate/Collate/CJK/Big5.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/Big5.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %u2p;
 my $wt = 0x8000;
diff --git a/cpan/Unicode-Collate/Collate/CJK/GB2312.pm 
b/cpan/Unicode-Collate/Collate/CJK/GB2312.pm
index f33eb69..89c5a13 100644
--- a/cpan/Unicode-Collate/Collate/CJK/GB2312.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/GB2312.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %u2p;
 my $wt = 0x8000;
diff --git a/cpan/Unicode-Collate/Collate/CJK/JISX0208.pm 
b/cpan/Unicode-Collate/Collate/CJK/JISX0208.pm
index 492496b..97bc4a7 100644
--- a/cpan/Unicode-Collate/Collate/CJK/JISX0208.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/JISX0208.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %u2p;
 my $wt = 0x8000;
diff --git a/cpan/Unicode-Collate/Collate/CJK/Korean.pm 
b/cpan/Unicode-Collate/Collate/CJK/Korean.pm
index 04ef676..ae11969 100644
--- a/cpan/Unicode-Collate/Collate/CJK/Korean.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/Korean.pm
@@ -4,21 +4,21 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %jamo2prim = (
-    '1100', 0x376F,   '1101', 0x3770,   '1102', 0x3771,   '1103', 0x3772,
-    '1105', 0x3774,   '1106', 0x3775,   '1107', 0x3776,   '1109', 0x3778,
-    '110A', 0x3779,   '110B', 0x377A,   '110C', 0x377B,   '110E', 0x377D,
-    '110F', 0x377E,   '1110', 0x377F,   '1111', 0x3780,   '1112', 0x3781,
-    '1161', 0x37ED,   '1162', 0x37EE,   '1163', 0x37EF,   '1165', 0x37F1,
-    '1166', 0x37F2,   '1167', 0x37F3,   '1168', 0x37F4,   '1169', 0x37F5,
-    '116A', 0x37F6,   '116B', 0x37F7,   '116C', 0x37F8,   '116D', 0x37F9,
-    '116E', 0x37FA,   '116F', 0x37FB,   '1170', 0x37FC,   '1171', 0x37FD,
-    '1172', 0x37FE,   '1173', 0x37FF,   '1174', 0x3800,   '1175', 0x3801,
-    '11A8', 0x384B,   '11AB', 0x384E,   '11AF', 0x3852,   '11B7', 0x385A,
-    '11B8', 0x385B,   '11BC', 0x385F,   '11BD', 0x3860,
-); # for DUCET v7.0.0
+    '1100', 0x3A5E,   '1101', 0x3A5F,   '1102', 0x3A60,   '1103', 0x3A61,
+    '1105', 0x3A63,   '1106', 0x3A64,   '1107', 0x3A65,   '1109', 0x3A67,
+    '110A', 0x3A68,   '110B', 0x3A69,   '110C', 0x3A6A,   '110E', 0x3A6C,
+    '110F', 0x3A6D,   '1110', 0x3A6E,   '1111', 0x3A6F,   '1112', 0x3A70,
+    '1161', 0x3ADC,   '1162', 0x3ADD,   '1163', 0x3ADE,   '1165', 0x3AE0,
+    '1166', 0x3AE1,   '1167', 0x3AE2,   '1168', 0x3AE3,   '1169', 0x3AE4,
+    '116A', 0x3AE5,   '116B', 0x3AE6,   '116C', 0x3AE7,   '116D', 0x3AE8,
+    '116E', 0x3AE9,   '116F', 0x3AEA,   '1170', 0x3AEB,   '1171', 0x3AEC,
+    '1172', 0x3AED,   '1173', 0x3AEE,   '1174', 0x3AEF,   '1175', 0x3AF0,
+    '11A8', 0x3B3A,   '11AB', 0x3B3D,   '11AF', 0x3B41,   '11B7', 0x3B49,
+    '11B8', 0x3B4A,   '11BC', 0x3B4E,   '11BD', 0x3B4F,
+); # for DUCET v8.0.0
 
 my(%u2e, $prim, $wt);
 while (<DATA>) {
diff --git a/cpan/Unicode-Collate/Collate/CJK/Pinyin.pm 
b/cpan/Unicode-Collate/Collate/CJK/Pinyin.pm
index 5abe650..5b62e39 100644
--- a/cpan/Unicode-Collate/Collate/CJK/Pinyin.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/Pinyin.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %u2p;
 my $wt = 0x8000;
diff --git a/cpan/Unicode-Collate/Collate/CJK/Stroke.pm 
b/cpan/Unicode-Collate/Collate/CJK/Stroke.pm
index e40e691..178044a 100644
--- a/cpan/Unicode-Collate/Collate/CJK/Stroke.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/Stroke.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %u2p;
 my $wt = 0x8000;
diff --git a/cpan/Unicode-Collate/Collate/CJK/Zhuyin.pm 
b/cpan/Unicode-Collate/Collate/CJK/Zhuyin.pm
index 13e4dc0..8e6eec2 100644
--- a/cpan/Unicode-Collate/Collate/CJK/Zhuyin.pm
+++ b/cpan/Unicode-Collate/Collate/CJK/Zhuyin.pm
@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my %u2p;
 my $wt = 0x8000;
diff --git a/cpan/Unicode-Collate/Collate/Locale.pm 
b/cpan/Unicode-Collate/Collate/Locale.pm
index f76abe5..74c3cc3 100644
--- a/cpan/Unicode-Collate/Collate/Locale.pm
+++ b/cpan/Unicode-Collate/Collate/Locale.pm
@@ -5,14 +5,14 @@ use warnings;
 use Carp;
 use base qw(Unicode::Collate);
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 
 my $PL_EXT  = '.pl';
 
 my %LocaleFile = map { ($_, $_) } qw(
-   af ar as az be bg bn ca cs cy da ee eo es et fa fi fil fo fr
+   af ar as az be bn ca cs cy da ee eo es et fa fi fil fo fr
    gu ha haw hi hr hu hy ig is ja kk kl kn ko kok ln lt lv
-   mk ml mr mt nb nn nso om or pa pl ro ru sa se si sk sl sq
+   mk ml mr mt nb nn nso om or pa pl ro sa se si sk sl sq
    sr sv ta te th tn to tr uk ur vi wae wo yo zh
 );
    $LocaleFile{'default'} = '';
@@ -26,6 +26,7 @@ my %LocaleFile = map { ($_, $_) } qw(
    $LocaleFile{'fi__phonebook'}   = 'fi_phone';
    $LocaleFile{'si__dictionary'}  = 'si_dict';
    $LocaleFile{'sv__reformed'}    = 'sv_refo';
+   $LocaleFile{'ug_Cyrl'}         = 'ug_cyrl';
    $LocaleFile{'zh__big5han'}     = 'zh_big5';
    $LocaleFile{'zh__gb2312han'}   = 'zh_gb';
    $LocaleFile{'zh__pinyin'}      = 'zh_pin';
@@ -125,97 +126,6 @@ sub new {
 1;
 __END__
 
-MEMORANDA for developing
-
-locale            based CLDR
-----------------------------------------------------------------------------
-af                22.1 = 1.8.1
-ar                22.1 = 1.9.0
-as                22.1 = 1.8.1
-az                22.1 = 1.8.1 (type="standard")
-be                22.1 = 1.9.0
-bg                22.1 = 1.9.0
-bn                22.1 = 2.0.1 (type="standard")
-bs                22.1 = 1.9.0 (alias source="hr")
-bs_Cyrl           22.1 = 22    (alias source="sr")
-ca                22.1 = 1.8.1 (alt="proposed" type="standard")
-cs                22.1 = 1.8.1 (type="standard")
-cy                22.1 = 1.8.1
-da                22.1 = 1.8.1 (type="standard") [mod aA to pass CLDR test]
-de__phonebook     22.1 = 2.0   (type="phonebook")
-ee                22.1 = 22
-eo                22.1 = 1.8.1
-es                22.1 = 1.9.0 (type="standard")
-es__traditional   22.1 = 1.8.1 (type="traditional")
-et                22.1 = 1.8.1
-fa                22.1 = 1.8.1
-fi                22.1 = 1.8.1 (type="standard" alt="proposed")
-fi__phonebook     22.1 = 1.8.1 (type="phonebook")
-fil               22.1 = 1.9.0 (type="standard") = 1.8.1
-fo                22.1 = 1.8.1 (alt="proposed" type="standard")
-fr                22.1 = 1.9.0 (fr_CA, backwards="on")
-gu                22.1 = 1.9.0 (type="standard")
-ha                22.1 = 1.9.0
-haw               22.1 = 1.8.1
-hi                22.1 = 1.9.0 (type="standard")
-hr                22.1 = 1.9.0 (type="standard")
-hu                22.1 = 1.8.1 (alt="proposed" type="standard")
-hy                22.1 = 1.8.1
-ig                22.1 = 1.8.1
-is                22.1 = 1.8.1 (type="standard")
-ja                22.1 = 1.8.1 (type="standard")
-kk                22.1 = 1.9.0
-kl                22.1 = 1.8.1 (type="standard")
-kn                22.1 = 1.9.0 (type="standard")
-ko                22.1 = 1.8.1 (type="standard")
-kok               22.1 = 1.8.1
-ln                22.1 = 2.0   (type="standard") = 1.8.1
-lt                22.1 = 1.9.0
-lv                22.1 = 1.9.0 (type="standard") = 1.8.1
-mk                22.1 = 1.9.0
-ml                22.1 = 1.9.0
-mr                22.1 = 1.8.1
-mt                22.1 = 1.9.0
-nb                22.1 = 2.0   (type="standard")
-nn                22.1 = 2.0   (type="standard")
-nso               22.1 = 1.8.1
-om                22.1 = 1.8.1
-or                22.1 = 1.9.0
-pa                22.1 = 1.8.1
-pl                22.1 = 1.8.1
-ro                22.1 = 1.9.0 (type="standard")
-ru                22.1 = 1.9.0
-sa                1.9.1 = 1.8.1 (type="standard" alt="proposed") [now /seed]
-se                22.1 = 1.8.1 (type="standard")
-si                22.1 = 1.9.0 (type="standard")
-si__dictionary    22.1 = 1.9.0 (type="dictionary")
-sk                22.1 = 1.9.0 (type="standard")
-sl                22.1 = 1.8.1 (type="standard" alt="proposed")
-sq                22.1 = 1.8.1 (alt="proposed" type="standard")
-sr                22.1 = 1.9.0 (type="standard")
-sr_Latn           22.1 = 1.8.1 (alias source="hr")
-sv                22.1 = 1.9.0 (type="standard")
-sv__reformed      22.1 = 1.8.1 (type="reformed")
-ta                22.1 = 1.9.0
-te                22.1 = 1.9.0
-th                22.1 = 22
-tn                22.1 = 1.8.1
-to                22.1 = 22
-tr                22.1 = 1.8.1 (type="standard")
-uk                22.1 = 21
-ur                22.1 = 1.9.0
-vi                22.1 = 1.8.1
-wae               22.1 = 2.0
-wo                1.9.1 = 1.8.1 [now /seed]
-yo                22.1 = 1.8.1
-zh                22.1 = 1.8.1 (type="standard")
-zh__big5han       22.1 = 1.8.1 (type="big5han")
-zh__gb2312han     22.1 = 1.8.1 (type="gb2312han")
-zh__pinyin        22.1 = 2.0   (type='pinyin' alt='short')
-zh__stroke        22.1 = 1.9.1 (type='stroke' alt='short')
-zh__zhuyin        22.1 = 22    (type='zhuyin' alt='short')
-----------------------------------------------------------------------------
-
 =head1 NAME
 
 Unicode::Collate::Locale - Linguistic tailoring for DUCET via Unicode::Collate
@@ -339,9 +249,8 @@ a combination of return values from C<getlocale> and 
C<locale_version>.
       as                Assamese
       az                Azerbaijani (Azeri)
       be                Belarusian
-      bg                Bulgarian
       bn                Bengali
-      bs                Bosnian
+      bs                Bosnian (tailored as Croatian)
       bs_Cyrl           Bosnian in Cyrillic (tailored as Serbian)
       ca                Catalan
       cs                Czech
@@ -389,7 +298,6 @@ a combination of return values from C<getlocale> and 
C<locale_version>.
       pa                Punjabi
       pl                Polish
       ro                Romanian
-      ru                Russian
       sa                Sanskrit
       se                Northern Sami
       si                Sinhala
@@ -407,6 +315,7 @@ a combination of return values from C<getlocale> and 
C<locale_version>.
       tn                Tswana
       to                Tonga
       tr                Turkish
+      ug_Cyrl           Uyghur in Cyrillic
       uk                Ukrainian
       ur                Urdu
       vi                Vietnamese
@@ -422,19 +331,21 @@ a combination of return values from C<getlocale> and 
C<locale_version>.
     --------------------------------------------------------------
 
 Locales according to the default UCA rules include
-chr (Cherokee),
+am (Amharic) without C<[reorder Ethi]>,
+bg (Bulgarian) without C<[reorder Cyrl]>,
+chr (Cherokee) without C<[reorder Cher]>,
 de (German),
 en (English),
 ga (Irish),
 id (Indonesian),
 it (Italian),
-ka (Georgian),
+ka (Georgian) without C<[reorder Geor]>,
+mn (Mongolian) without C<[reorder Cyrl Mong]>,
 ms (Malay),
 nl (Dutch),
 pt (Portuguese),
-st (Southern Sotho),
+ru (Russian) without C<[reorder Cyrl]>,
 sw (Swahili),
-xh (Xhosa),
 zu (Zulu).
 
 B<Note>
@@ -477,11 +388,102 @@ Thus C<(normalization =E<gt> undef)> is less preferred.
 
 =back
 
+=head2 Reference
+
+      locale            based CLDR or other reference
+    --------------------------------------------------------------------
+      af                22.1 = 1.8.1
+      ar                22.1 = 1.9.0
+      as                22.1 = 1.8.1
+      az                22.1 = 1.8.1 (type="standard")
+      be                30 = 28 (type="standard" without [reorder Cyrl])
+      bn                22.1 = 2.0.1 (type="standard")
+      bs                30 = 28 (type="standard": [import hr])
+      bs_Cyrl           30 = 28 (type="standard": [import sr])
+      ca                22.1 = 1.8.1 (alt="proposed" type="standard")
+      cs                22.1 = 1.8.1 (type="standard")
+      cy                22.1 = 1.8.1
+      da                22.1 = 1.8.1 (type="standard")
+      de__phonebook     22.1 = 2.0   (type="phonebook")
+      ee                22.1 = 22
+      eo                22.1 = 1.8.1
+      es                22.1 = 1.9.0 (type="standard")
+      es__traditional   22.1 = 1.8.1 (type="traditional")
+      et                22.1 = 1.8.1
+      fa                22.1 = 1.8.1
+      fi                22.1 = 1.8.1 (type="standard" alt="proposed")
+      fi__phonebook     22.1 = 1.8.1 (type="phonebook")
+      fil               22.1 = 1.9.0 (type="standard") = 1.8.1
+      fo                22.1 = 1.8.1 (alt="proposed" type="standard")
+      fr                22.1 = 1.9.0 (fr_CA, backwards="on")
+      gu                22.1 = 1.9.0 (type="standard")
+      ha                22.1 = 1.9.0
+      haw               22.1 = 1.8.1
+      hi                22.1 = 1.9.0 (type="standard")
+      hr                22.1 = 1.9.0 (type="standard")
+      hu                22.1 = 1.8.1 (alt="proposed" type="standard")
+      hy                22.1 = 1.8.1
+      ig                22.1 = 1.8.1
+      is                22.1 = 1.8.1 (type="standard")
+      ja                22.1 = 1.8.1 (type="standard")
+      kk                30 = 28 (type="standard" without [reorder Cyrl])
+      kl                22.1 = 1.8.1 (type="standard")
+      kn                22.1 = 1.9.0 (type="standard")
+      ko                22.1 = 1.8.1 (type="standard")
+      kok               22.1 = 1.8.1
+      ln                22.1 = 2.0   (type="standard") = 1.8.1
+      lt                22.1 = 1.9.0
+      lv                22.1 = 1.9.0 (type="standard") = 1.8.1
+      mk                30 = 28 (type="standard" without [reorder Cyrl])
+      ml                22.1 = 1.9.0
+      mr                22.1 = 1.8.1
+      mt                22.1 = 1.9.0
+      nb                22.1 = 2.0   (type="standard")
+      nn                22.1 = 2.0   (type="standard")
+      nso               22.1 = 1.8.1
+      om                22.1 = 1.8.1
+      or                22.1 = 1.9.0
+      pa                22.1 = 1.8.1
+      pl                22.1 = 1.8.1
+      ro                22.1 = 1.9.0 (type="standard")
+      sa                1.9.1 = 1.8.1 (type="standard" alt="proposed")
+                                      [now in /seed]
+      se                22.1 = 1.8.1 (type="standard")
+      si                22.1 = 1.9.0 (type="standard")
+      si__dictionary    22.1 = 1.9.0 (type="dictionary")
+      sk                22.1 = 1.9.0 (type="standard")
+      sl                22.1 = 1.8.1 (type="standard" alt="proposed")
+      sq                22.1 = 1.8.1 (alt="proposed" type="standard")
+      sr                30 = 28 (type="standard" without [reorder Cyrl])
+      sr_Latn           30 = 28 (type="standard": [import hr])
+      sv                22.1 = 1.9.0 (type="standard")
+      sv__reformed      22.1 = 1.8.1 (type="reformed")
+      ta                22.1 = 1.9.0
+      te                22.1 = 1.9.0
+      th                22.1 = 22
+      tn                22.1 = 1.8.1
+      to                22.1 = 22
+      tr                22.1 = 1.8.1 (type="standard")
+      uk                30 = 28 (type="standard" without [reorder Cyrl])
+      ug_Cyrl           https://en.wikipedia.org/wiki/Uyghur_Cyrillic_alphabet
+      ur                22.1 = 1.9.0
+      vi                22.1 = 1.8.1
+      wae               22.1 = 2.0
+      wo                1.9.1 = 1.8.1 [now in /seed]
+      yo                22.1 = 1.8.1
+      zh                22.1 = 1.8.1 (type="standard")
+      zh__big5han       22.1 = 1.8.1 (type="big5han")
+      zh__gb2312han     22.1 = 1.8.1 (type="gb2312han")
+      zh__pinyin        22.1 = 2.0   (type='pinyin' alt='short')
+      zh__stroke        22.1 = 1.9.1 (type='stroke' alt='short')
+      zh__zhuyin        22.1 = 22    (type='zhuyin' alt='short')
+    --------------------------------------------------------------------
+
 =head1 AUTHOR
 
 The Unicode::Collate::Locale module for perl was written
 by SADAHIRO Tomoyuki, <[email protected]>.
-This module is Copyright(C) 2004-2013, SADAHIRO Tomoyuki. Japan.
+This module is Copyright(C) 2004-2016, SADAHIRO Tomoyuki. Japan.
 All rights reserved.
 
 This module is free software; you can redistribute it and/or
diff --git a/cpan/Unicode-Collate/Collate/Locale/af.pl 
b/cpan/Unicode-Collate/Collate/Locale/af.pl
index 1a3a479..b74b0a7 100644
--- a/cpan/Unicode-Collate/Collate/Locale/af.pl
+++ b/cpan/Unicode-Collate/Collate/Locale/af.pl
@@ -1,6 +1,6 @@
 +{
-   locale_version => 1.14,
-   entry => <<'ENTRY', # for DUCET v7.0.0
-0149      ; [.1A7D.0020.0009] # LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
+   locale_version => 1.17,
+   entry => <<'ENTRY', # for DUCET v8.0.0
+0149      ; [.1D34.0020.0009] # LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
 ENTRY
 };
diff --git a/cpan/Unicode-Collate/Collate/Locale/ar.pl 
b/cpan/Unicode-Collate/Collate/Locale/ar.pl
index cf27cfd..27738bb 100644
--- a/cpan/Unicode-Collate/Collate/Locale/ar.pl
+++ b/cpan/Unicode-Collate/Collate/Locale/ar.pl
@@ -1,15 +1,15 @@
 +{
-   locale_version => 1.14,
-   entry => <<'ENTRY', # for DUCET v7.0.0
-0629      ; [.2025.0021.0002] # ARABIC LETTER TEH MARBUTA
-FE94      ; [.2025.0021.0019] # ARABIC LETTER TEH MARBUTA FINAL FORM
-FE93      ; [.2025.0021.001A] # ARABIC LETTER TEH MARBUTA ISOLATED FORM
-0649      ; [.20C7.0021.0002] # ARABIC LETTER ALEF MAKSURA
-FBE8      ; [.20C7.0021.0017] # ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF 
MAKSURA INITIAL FORM
-FBE9      ; [.20C7.0021.0018] # ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF 
MAKSURA MEDIAL FORM
-FEF0      ; [.20C7.0021.0019] # ARABIC LETTER ALEF MAKSURA FINAL FORM
-FEEF      ; [.20C7.0021.001A] # ARABIC LETTER ALEF MAKSURA ISOLATED FORM
-FC90      ; [.20C7.0021.001B] # ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT 
ALEF FINAL FORM
-FC5D      ; [.20C7.0021.001C] # ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT 
ALEF ISOLATED FORM
+   locale_version => 1.17,
+   entry => <<'ENTRY', # for DUCET v8.0.0
+0629      ; [.2296.0021.0002] # ARABIC LETTER TEH MARBUTA
+FE94      ; [.2296.0021.0019] # ARABIC LETTER TEH MARBUTA FINAL FORM
+FE93      ; [.2296.0021.001A] # ARABIC LETTER TEH MARBUTA ISOLATED FORM
+0649      ; [.233A.0021.0002] # ARABIC LETTER ALEF MAKSURA
+FBE8      ; [.233A.0021.0017] # ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF 
MAKSURA INITIAL FORM
+FBE9      ; [.233A.0021.0018] # ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF 
MAKSURA MEDIAL FORM
+FEF0      ; [.233A.0021.0019] # ARABIC LETTER ALEF MAKSURA FINAL FORM
+FEEF      ; [.233A.0021.001A] # ARABIC LETTER ALEF MAKSURA ISOLATED FORM
+FC90      ; [.233A.0021.001B] # ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT 
ALEF FINAL FORM
+FC5D      ; [.233A.0021.001C] # ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT 
ALEF ISOLATED FORM
 ENTRY
 };
diff --git a/cpan/Unicode-Collate/Collate/Locale/as.pl 
b/cpan/Unicode-Collate/Collate/Locale/as.pl
index 9a869cf..6b2abec 100644
--- a/cpan/Unicode-Collate/Collate/Locale/as.pl
+++ b/cpan/Unicode-Collate/Collate/Locale/as.pl
@@ -1,13 +1,13 @@
 +{
-   locale_version => 1.14,
-   entry => <<'ENTRY', # for DUCET v7.0.0
-0982      ; [.23CC.0020.0002][.FFF1.0000.0000] # BENGALI SIGN ANUSVARA
-0981      ; [.23CC.0020.0002][.FFF2.0000.0000] # BENGALI SIGN CANDRABINDU
-0983      ; [.23CC.0020.0002][.FFF3.0000.0000] # BENGALI SIGN VISARGA
-0994      ; [.23CC.0020.0002][.FFF0.0000.0000] # BENGALI LETTER AU
-09A4 09CD 200D ; [.23DB.0020.0002][.FFF1.0000.0000] # <BENGALI LETTER TA, 
BENGALI SIGN VIRAMA, ZERO WIDTH JOINER>
-09A3      ; [.23DB.0020.0002][.FFF0.0000.0000] # BENGALI LETTER NNA
-0995 09CD 09B7 ; [.23EE.0020.0002][.FFF1.0000.0000] # <BENGALI LETTER KA, 
BENGALI SIGN VIRAMA, BENGALI LETTER SSA>
-09B9      ; [.23EE.0020.0002][.FFF0.0000.0000] # BENGALI LETTER HA
+   locale_version => 1.17,
+   entry => <<'ENTRY', # for DUCET v8.0.0
+0982      ; [.2640.0020.0002][.FFF1.0000.0000] # BENGALI SIGN ANUSVARA
+0981      ; [.2640.0020.0002][.FFF2.0000.0000] # BENGALI SIGN CANDRABINDU
+0983      ; [.2640.0020.0002][.FFF3.0000.0000] # BENGALI SIGN VISARGA
+0994      ; [.2640.0020.0002][.FFF0.0000.0000] # BENGALI LETTER AU
+09A4 09CD 200D ; [.264F.0020.0002][.FFF1.0000.0000] # <BENGALI LETTER TA, 
BENGALI SIGN VIRAMA, ZERO WIDTH JOINER>
+09A3      ; [.264F.0020.0002][.FFF0.0000.0000] # BENGALI LETTER NNA
+0995 09CD 09B7 ; [.2662.0020.0002][.FFF1.0000.0000] # <BENGALI LETTER KA, 
BENGALI SIGN VIRAMA, BENGALI LETTER SSA>
+09B9      ; [.2662.0020.0002][.FFF0.0000.0000] # BENGALI LETTER HA
 ENTRY
 };
diff --git a/cpan/Unicode-Collate/Collate/Locale/az.pl 
b/cpan/Unicode-Collate/Collate/Locale/az.pl
index c405fc5..b0b7725 100644
--- a/cpan/Unicode-Collate/Collate/Locale/az.pl
+++ b/cpan/Unicode-Collate/Collate/Locale/az.pl
@@ -1,51 +1,51 @@
 +{
-   locale_version => 1.14,
+   locale_version => 1.17,
 # schwa doesn't require tailoring
-   entry => <<'ENTRY', # for DUCET v7.0.0
-00E7      ; [.193F.0020.0002] # LATIN SMALL LETTER C WITH CEDILLA
-0063 0327 ; [.193F.0020.0002] # LATIN SMALL LETTER C WITH CEDILLA
-00C7      ; [.193F.0020.0008] # LATIN CAPITAL LETTER C WITH CEDILLA
-0043 0327 ; [.193F.0020.0008] # LATIN CAPITAL LETTER C WITH CEDILLA
-011F      ; [.19B9.0020.0002] # LATIN SMALL LETTER G WITH BREVE
-0067 0306 ; [.19B9.0020.0002] # LATIN SMALL LETTER G WITH BREVE
-011E      ; [.19B9.0020.0008] # LATIN CAPITAL LETTER G WITH BREVE
-0047 0306 ; [.19B9.0020.0008] # LATIN CAPITAL LETTER G WITH BREVE
-0131      ; [.19F5.0020.0002] # LATIN SMALL LETTER DOTLESS I
-0049      ; [.19F5.0020.0008] # LATIN CAPITAL LETTER I
-00CC      ; [.19F5.0020.0008][.0000.0025.0002] # LATIN CAPITAL LETTER I WITH 
GRAVE
-00CD      ; [.19F5.0020.0008][.0000.0024.0002] # LATIN CAPITAL LETTER I WITH 
ACUTE
-00CE      ; [.19F5.0020.0008][.0000.0027.0002] # LATIN CAPITAL LETTER I WITH 
CIRCUMFLEX
-00CF      ; [.19F5.0020.0008][.0000.002B.0002] # LATIN CAPITAL LETTER I WITH 
DIAERESIS
-012A      ; [.19F5.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER I WITH 
MACRON
-012C      ; [.19F5.0020.0008][.0000.0026.0002] # LATIN CAPITAL LETTER I WITH 
BREVE
-012E      ; [.19F5.0020.0008][.0000.0031.0002] # LATIN CAPITAL LETTER I WITH 
OGONEK
-0130      ; [.19F6.0020.0008] # LATIN CAPITAL LETTER I WITH DOT ABOVE
-0049 0307 ; [.19F6.0020.0008] # LATIN CAPITAL LETTER I WITH DOT ABOVE
-00F6      ; [.1AA2.0020.0002] # LATIN SMALL LETTER O WITH DIAERESIS
-006F 0308 ; [.1AA2.0020.0002] # LATIN SMALL LETTER O WITH DIAERESIS
-00D6      ; [.1AA2.0020.0008] # LATIN CAPITAL LETTER O WITH DIAERESIS
-004F 0308 ; [.1AA2.0020.0008] # LATIN CAPITAL LETTER O WITH DIAERESIS
-022B      ; [.1AA2.0020.0002][.0000.0032.0002] # LATIN SMALL LETTER O WITH 
DIAERESIS AND MACRON
-022A      ; [.1AA2.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER O WITH 
DIAERESIS AND MACRON
-015F      ; [.1B34.0020.0002] # LATIN SMALL LETTER S WITH CEDILLA
-0073 0327 ; [.1B34.0020.0002] # LATIN SMALL LETTER S WITH CEDILLA
-015E      ; [.1B34.0020.0008] # LATIN CAPITAL LETTER S WITH CEDILLA
-0053 0327 ; [.1B34.0020.0008] # LATIN CAPITAL LETTER S WITH CEDILLA
-00FC      ; [.1B78.0020.0002] # LATIN SMALL LETTER U WITH DIAERESIS
-0075 0308 ; [.1B78.0020.0002] # LATIN SMALL LETTER U WITH DIAERESIS
-00DC      ; [.1B78.0020.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
-0055 0308 ; [.1B78.0020.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
-01DC      ; [.1B78.0020.0002][.0000.0025.0002] # LATIN SMALL LETTER U WITH 
DIAERESIS AND GRAVE
-01DB      ; [.1B78.0020.0008][.0000.0025.0002] # LATIN CAPITAL LETTER U WITH 
DIAERESIS AND GRAVE
-01D8      ; [.1B78.0020.0002][.0000.0024.0002] # LATIN SMALL LETTER U WITH 
DIAERESIS AND ACUTE
-01D7      ; [.1B78.0020.0008][.0000.0024.0002] # LATIN CAPITAL LETTER U WITH 
DIAERESIS AND ACUTE
-01D6      ; [.1B78.0020.0002][.0000.0032.0002] # LATIN SMALL LETTER U WITH 
DIAERESIS AND MACRON
-01D5      ; [.1B78.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER U WITH 
DIAERESIS AND MACRON
-01DA      ; [.1B78.0020.0002][.0000.0028.0002] # LATIN SMALL LETTER U WITH 
DIAERESIS AND CARON
-01D9      ; [.1B78.0020.0008][.0000.0028.0002] # LATIN CAPITAL LETTER U WITH 
DIAERESIS AND CARON
-0071      ; [.1A2A.0020.0002] # LATIN SMALL LETTER Q
-0051      ; [.1A2A.0020.0008] # LATIN CAPITAL LETTER Q
-0078      ; [.19DD.0020.0002] # LATIN SMALL LETTER X
-0058      ; [.19DD.0020.0008] # LATIN CAPITAL LETTER X
+   entry => <<'ENTRY', # for DUCET v8.0.0
+00E7      ; [.1BF6.0020.0002] # LATIN SMALL LETTER C WITH CEDILLA
+0063 0327 ; [.1BF6.0020.0002] # LATIN SMALL LETTER C WITH CEDILLA
+00C7      ; [.1BF6.0020.0008] # LATIN CAPITAL LETTER C WITH CEDILLA
+0043 0327 ; [.1BF6.0020.0008] # LATIN CAPITAL LETTER C WITH CEDILLA
+011F      ; [.1C70.0020.0002] # LATIN SMALL LETTER G WITH BREVE
+0067 0306 ; [.1C70.0020.0002] # LATIN SMALL LETTER G WITH BREVE
+011E      ; [.1C70.0020.0008] # LATIN CAPITAL LETTER G WITH BREVE
+0047 0306 ; [.1C70.0020.0008] # LATIN CAPITAL LETTER G WITH BREVE
+0131      ; [.1CAC.0020.0002] # LATIN SMALL LETTER DOTLESS I
+0049      ; [.1CAC.0020.0008] # LATIN CAPITAL LETTER I
+00CC      ; [.1CAC.0020.0008][.0000.0025.0002] # LATIN CAPITAL LETTER I WITH 
GRAVE
+00CD      ; [.1CAC.0020.0008][.0000.0024.0002] # LATIN CAPITAL LETTER I WITH 
ACUTE
+00CE      ; [.1CAC.0020.0008][.0000.0027.0002] # LATIN CAPITAL LETTER I WITH 
CIRCUMFLEX
+00CF      ; [.1CAC.0020.0008][.0000.002B.0002] # LATIN CAPITAL LETTER I WITH 
DIAERESIS
+012A      ; [.1CAC.0020.0008][.0000.0032.0002] # LATIN CAPITAL LETTER I WITH 
MACRON
+012C      ; [.1CAC.0020.0008][.0000.0026.0002] # LATIN CAPITAL LETTER I WITH 
BREVE
+012E      ; [.1CAC.0020.0008][.0000.0031.0002] # LATIN CAPITAL LETTER I WITH 
OGONEK
+0130      ; [.1CAD.0020.0008] # LATIN CAPITAL LETTER I WITH DOT ABOVE
+0049 0307 ; [.1CAD.0020.0008] # LATIN CAPITAL LETTER I WITH DOT ABOVE
**** PATCH TRUNCATED AT 2000 LINES -- 70717 NOT SHOWN ****

diff --git a/cpan/Term-ANSIColor/t/lib/Test/RRA/Config.pm 
b/cpan/Term-ANSIColor/t/lib/Test/RRA/Config.pm
index 3110324..bdb31e6 100644
--- a/cpan/Term-ANSIColor/t/lib/Test/RRA/Config.pm
+++ b/cpan/Term-ANSIColor/t/lib/Test/RRA/Config.pm
@@ -34,16 +34,16 @@ BEGIN {
     # This version should match the corresponding rra-c-util release, but with
     # two digits for the minor version, including a leading zero if necessary,
     # so that it will sort properly.
-    $VERSION = '5.11';
+    $VERSION = '6.02';
 }
 
 # If BUILD or SOURCE are set in the environment, look for data/perl.conf under
 # those paths for a C Automake package.  Otherwise, look in t/data/perl.conf
 # for a standalone Perl module or tests/data/perl.conf for Perl tests embedded
 # in a larger distribution.  Don't use Test::RRA::Automake since it may not
 # exist.
 our $PATH;
-for my $base ($ENV{BUILD}, $ENV{SOURCE}, 't', 'tests') {
+for my $base ($ENV{C_TAP_BUILD}, $ENV{C_TAP_SOURCE}, './t', './tests') {
     next if !defined($base);
     my $path = "$base/data/perl.conf";
     if (-r $path) {
@@ -70,7 +70,7 @@ our @STRICT_PREREQ;
 # Load the configuration.
 if (!do($PATH)) {
     my $error = $@ || $! || 'loading file did not return true';
-    BAIL_OUT("cannot load data/perl.conf: $error");
+    BAIL_OUT("cannot load $PATH: $error");
 }
 
 1;
@@ -98,10 +98,10 @@ for both C Automake packages and stand-alone Perl modules.
 
 Test::RRA::Config looks for a file named F<data/perl.conf> relative to the
 root of the test directory.  That root is taken from the environment variables
-BUILD or SOURCE (in that order) if set, which will be the case for C Automake
-packages using C TAP Harness.  If neither is set, it expects the root of the
-test directory to be a directory named F<t> relative to the current directory,
-which will be the case for stand-alone Perl modules.
+C_TAP_BUILD or C_TAP_SOURCE (in that order) if set, which will be the case for
+C Automake packages using C TAP Harness.  If neither is set, it expects the
+root of the test directory to be a directory named F<t> relative to the
+current directory, which will be the case for stand-alone Perl modules.
 
 The following variables are supported:
 
@@ -185,6 +185,8 @@ Russ Allbery <[email protected]>
 
 =head1 COPYRIGHT AND LICENSE
 
+Copyright 2015, 2016 Russ Allbery <[email protected]>
+
 Copyright 2013, 2014 The Board of Trustees of the Leland Stanford Junior
 University
 
@@ -212,9 +214,9 @@ perlcritic(1), Test::MinimumVersion(3), Test::RRA(3), 
Test::RRA::Automake(3),
 Test::Strict(3)
 
 This module is maintained in the rra-c-util package.  The current version is
-available from L<http://www.eyrie.org/~eagle/software/rra-c-util/>.
+available from L<https://www.eyrie.org/~eagle/software/rra-c-util/>.
 
 The C TAP Harness test driver and libraries for TAP-based C testing are
-available from L<http://www.eyrie.org/~eagle/software/c-tap-harness/>.
+available from L<https://www.eyrie.org/~eagle/software/c-tap-harness/>.
 
 =cut
@@ -34,16 +34,16 @@ BEGIN {
 }
 
-# If BUILD or SOURCE are set in the environment, look for data/perl.conf under
-# those paths for a C Automake package.  Otherwise, look in t/data/perl.conf
-# for a standalone Perl module or tests/data/perl.conf for Perl tests embedded
-# in a larger distribution.  Don't use Test::RRA::Automake since it may not
-# exist.
+# If C_TAP_BUILD or C_TAP_SOURCE are set in the environment, look for
+# data/perl.conf under those paths for a C Automake package.  Otherwise, look
+# in t/data/perl.conf for a standalone Perl module or tests/data/perl.conf for
+# Perl tests embedded in a larger distribution.  Don't use Test::RRA::Automake
+# since it may not exist.
 our $PATH;
--
Perl5 Master Repository

Reply via email to